using System;
using System.Data;
using CrystalDecisions.CrystalReports.Engine;
using CrystalDecisions.Shared;
//Using the broken rules of the ProlongedTransfusionReport because they are the same as
//the rules for the CostAccountingReport
using BROKEN = EXT.DOMAIN.vbecs.Common.VbecsBrokenRules.ProlongedTransfusionReport;
using TABLE = EXT.DOMAIN.vbecs.Common.VbecsTables;
using ARTIFICIAL = EXT.DOMAIN.vbecs.Common.DatabaseConstants.ArtificialColumnNames;
namespace EXT.DOMAIN.vbecs.BOL
/// <summary>
/// Summary description for CostAccountingReport.
/// </summary>
public class CostAccountingReport : VbecsReport
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>8/24/2004</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="2665"> 
///
<ExpectedInput>start date, end date</ExpectedInput>
///
<ExpectedOutput>CostAccountingReport object</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="2667"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
/// <summary>
/// Constructor
/// </summary>
/// <param name="startDate"></param>
/// <param name="endDate"></param>
public CostAccountingReport(DateTime startDate, DateTime endDate)
this.StartDate = startDate;
this.EndDate = endDate;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>1/6/2005</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="6127"> 
///
<ExpectedInput>Valid Parameters</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="6128"> 
///
<ExpectedInput>Invalid Parameters</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
/// <summary>
/// Blank Constructor
/// </summary>
public CostAccountingReport()
SetInitialBrokenRules( BROKEN.FormClassName, BROKEN.RuleSets.BaseRuleSet );
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>8/24/2004</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="5440"> 
///
<ExpectedInput>Common.CostAccountingReportSections.IncomingShipment</ExpectedInput>
///
<ExpectedOutput>DataTable containig IncomingShipment data</ExpectedOutput>
///
</Case>
///
///<Case type="0" testid ="5441"> 
///
<ExpectedInput>Common.CostAccountingReportSections.OutgoingShipment</ExpectedInput>
///
<ExpectedOutput>DataTable containig OutgoingShipment data</ExpectedOutput>
///
</Case>
///
///
///<Case type="0" testid ="5442"> 
///
<ExpectedInput>Common.CostAccountingReportSections.UnitModification</ExpectedInput>
///
<ExpectedOutput>DataTable containing UnitModification data</ExpectedOutput>
///
</Case>
///
///<Case type="0" testid ="5443"> 
///
<ExpectedInput>Common.CostAccountingReportSections.OffSiteABID</ExpectedInput>
///
<ExpectedOutput>DataTable containing OffSiteABID data</ExpectedOutput>
///
</Case>
///
///<Case type="0" testid ="5444"> 
///
<ExpectedInput>Common.CostAccountingReportSections.DiscardedUnit</ExpectedInput>
///
<ExpectedOutput>DataTable containing DisardedUnit data</ExpectedOutput>
///
</Case>
///
///<Case type="0" testid ="5445"> 
///
<ExpectedInput>Common.CostAccountingReportSections.Main</ExpectedInput>
///
<ExpectedOutput>DataTable containing data for the main report</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="5446"> 
///
<ExpectedInput>Common.CostAccountingReportSections.Unknown</ExpectedInput>
///
<ExpectedOutput>Empty DataTable</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Generate data source for Cost Accounting Report
/// </summary>
/// <param name="reportSection"></param>
/// <returns></returns>
public DataTable GetCostAccountingReport(Common.CostAccountingReportSections reportSection)
DataTable dtCostAccounting = null;
switch(reportSection)
case Common.CostAccountingReportSections.IncomingShipment:
dtCostAccounting = DAL.Shipment.GetIncomingShipments(this.StartDate, this.EndDate);
dtCostAccounting.Columns.Add(ARTIFICIAL.ABORh);
//converting ShipmentGuid column of type Guid to ShipmentGuid column of type string - used to group records on report
//grouping does not work on Guid type columns
dtCostAccounting.Columns[TABLE.Shipment.ShipmentGuid].ColumnName = ARTIFICIAL.Guid;
dtCostAccounting.Columns.Add(TABLE.Shipment.ShipmentGuid);
foreach(DataRow drIncomingShipment in dtCostAccounting.Rows)
drIncomingShipment[ARTIFICIAL.ABORh] = drIncomingShipment[TABLE.BloodUnitMedia.BloodTypeCode].ToString().Trim();
drIncomingShipment[ARTIFICIAL.ABORh] += " ";
drIncomingShipment[ARTIFICIAL.ABORh] += drIncomingShipment[TABLE.RhFactor.RhFactorText].ToString().Trim();
if (drIncomingShipment.IsNull(TABLE.BloodUnitFinance.UnitCost))
drIncomingShipment[TABLE.BloodUnitFinance.UnitCost] = 0;
if (drIncomingShipment.IsNull(TABLE.BloodUnitFinance.SpecialTestingCost))
drIncomingShipment[TABLE.BloodUnitFinance.SpecialTestingCost] = 0;
drIncomingShipment[TABLE.Shipment.ShipmentGuid] = drIncomingShipment[ARTIFICIAL.Guid].ToString();
dtCostAccounting.Columns.Remove(ARTIFICIAL.Guid);
break;
case Common.CostAccountingReportSections.OutgoingShipment:
dtCostAccounting = DAL.Shipment.GetOutgoingShipments(this.StartDate, this.EndDate);
//converting ShipmentGuid column of type Guid to ShipmentGuid column of type string - used to group records on report
//grouping does not work on Guid type columns
dtCostAccounting.Columns[TABLE.Shipment.ShipmentGuid].ColumnName = ARTIFICIAL.Guid;
dtCostAccounting.Columns.Add(TABLE.Shipment.ShipmentGuid);
foreach(DataRow drOutgoingShipment in dtCostAccounting.Rows)
drOutgoingShipment[TABLE.Shipment.ShipmentGuid] = drOutgoingShipment[ARTIFICIAL.Guid].ToString();
if (drOutgoingShipment.IsNull(TABLE.BloodUnitFinance.ReturnCreditAmount))
drOutgoingShipment[TABLE.BloodUnitFinance.ReturnCreditAmount] = 0;
dtCostAccounting.Columns.Remove(ARTIFICIAL.Guid);
break;
case Common.CostAccountingReportSections.Modifications:
dtCostAccounting = DAL.BloodUnitModification.GetUnitModifications(this.StartDate, this.EndDate);
break;
case Common.CostAccountingReportSections.OffSiteABID:
dtCostAccounting = DAL.SpecimenTest.GetOffSiteAntibodyIDs(this.StartDate, this.EndDate);
break;
case Common.CostAccountingReportSections.DiscardedUnits:
dtCostAccounting = DAL.BloodUnit.GetDiscardedUnits(this.StartDate, this.EndDate);
dtCostAccounting.Columns.Add(ARTIFICIAL.DiscardType);
foreach(DataRow drDiscardedUnit in dtCostAccounting.Rows)
if (drDiscardedUnit.IsNull(TABLE.BloodUnitFinance.ReturnCreditAmount))
drDiscardedUnit[ARTIFICIAL.DiscardType] = "Waste";
else
drDiscardedUnit[ARTIFICIAL.DiscardType] = "Credit";
break;
case Common.CostAccountingReportSections.InactivatedUnits:
dtCostAccounting = DAL.BloodUnit.GetInactivatedUnitsList(this.StartDate, this.EndDate);
break;
case Common.CostAccountingReportSections.Main:
dtCostAccounting = new DataTable();
dtCostAccounting.Columns.Add(ARTIFICIAL.IncomingShipmentsVisibleIndicator, typeof(bool));
dtCostAccounting.Columns.Add(ARTIFICIAL.OutgoingShipmentsVisibleIndicator, typeof(bool));
dtCostAccounting.Columns.Add(ARTIFICIAL.UnitModificationsVisibleIndicator, typeof(bool));
dtCostAccounting.Columns.Add(ARTIFICIAL.OffSiteABIDsVisibleIndicator, typeof(bool));
dtCostAccounting.Columns.Add(ARTIFICIAL.DiscardedUnitsVisibleIndicator, typeof(bool));
dtCostAccounting.Columns.Add(ARTIFICIAL.InactivatedUnitsVisibleIndicator, typeof(bool));
DataSet dsCostAccounting = new DataSet();
dsCostAccounting.Tables.Add(dtCostAccounting);
break;
default:
dtCostAccounting = new DataTable();
break;
return dtCostAccounting;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>1/6/2005</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="6125"> 
///
<ExpectedInput>Valid cost accounting report object</ExpectedInput>
///
<ExpectedOutput>report generated</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="6126"> 
///
<ExpectedInput>N/A</ExpectedInput>
///
<ExpectedOutput>N/A</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
/// <summary>
/// GenerateReport
/// </summary>
/// <param name="PrintedBy"> User who is printing the report</param>
/// <returns></returns>
public va.med.vbecs.reports.CostAccountingReport.CostAccountingReport GenerateReport(string PrintedBy)
string reportCriteria = "Date Range: ";
reportCriteria += Common.VBECSDateTime.FormatDateString(this.StartDate);
reportCriteria += " - ";
reportCriteria += Common.VBECSDateTime.FormatDateString(this.EndDate);
DataSet dsHeader =  BOL.VbecsReport.GetReportHeader(PrintedBy);
DataSet dsFooter = BOL.VbecsReport.GetReportFooter(reportCriteria);
va.med.vbecs.reports.CostAccountingReport.CostAccountingReport _rptCostAccountingReport = new reports.CostAccountingReport.CostAccountingReport();
DataTable dtIncomingShipments = this.GetCostAccountingReport(Common.CostAccountingReportSections.IncomingShipment);
DataTable dtOutgoingShipments = this.GetCostAccountingReport(Common.CostAccountingReportSections.OutgoingShipment);
DataTable dtUnitModifications = this.GetCostAccountingReport(Common.CostAccountingReportSections.Modifications);
DataTable dtOffSiteABIDs = this.GetCostAccountingReport(Common.CostAccountingReportSections.OffSiteABID);
DataTable dtDiscardedUnits = this.GetCostAccountingReport(Common.CostAccountingReportSections.DiscardedUnits);
DataTable dtMainReport = this.GetCostAccountingReport(Common.CostAccountingReportSections.Main);
DataRow drMainReport = dtMainReport.NewRow();
foreach (ReportObject reportObj in _rptCostAccountingReport.ReportDefinition.ReportObjects)
if (reportObj.Kind != ReportObjectKind.SubreportObject)
continue;
SubreportObject subreportObj = (SubreportObject)reportObj;
ReportDocument reportDoc = subreportObj.OpenSubreport(subreportObj.SubreportName);
if (subreportObj.SubreportName == "ReportHeader.rpt")
reportDoc.SetDataSource( dsHeader );
else if (subreportObj.SubreportName == "ReportFooter.rpt")
reportDoc.SetDataSource( dsFooter );
else if (subreportObj.SubreportName == "IncomingShipments.rpt")
if (dtIncomingShipments.Rows.Count>0 && dtIncomingShipments != null)
drMainReport[ARTIFICIAL.IncomingShipmentsVisibleIndicator]=true;
reportDoc.SetDataSource( dtIncomingShipments );
else if (subreportObj.SubreportName == "OutgoingShipments.rpt")
if (dtOutgoingShipments.Rows.Count>0 && dtOutgoingShipments != null)
drMainReport[ARTIFICIAL.OutgoingShipmentsVisibleIndicator] = true;
reportDoc.SetDataSource( dtOutgoingShipments );
else if (subreportObj.SubreportName == "UnitModifications.rpt")
if (dtUnitModifications.Rows.Count>0 && dtUnitModifications != null)
drMainReport[ARTIFICIAL.UnitModificationsVisibleIndicator]=true;
reportDoc.SetDataSource( dtUnitModifications );
else if (subreportObj.SubreportName == "OffSiteABIDs.rpt")
if (dtOffSiteABIDs.Rows.Count>0 && dtOffSiteABIDs != null)
drMainReport[ARTIFICIAL.OffSiteABIDsVisibleIndicator]=true;
reportDoc.SetDataSource( dtOffSiteABIDs );
else if (subreportObj.SubreportName == "DiscardedUnits.rpt")
if (dtDiscardedUnits.Rows.Count>0 && dtDiscardedUnits != null)
drMainReport[ARTIFICIAL.DiscardedUnitsVisibleIndicator]=true;
reportDoc.SetDataSource(dtDiscardedUnits);
dtMainReport.Rows.Add(drMainReport);
_rptCostAccountingReport.SetDataSource( dtMainReport );
return _rptCostAccountingReport;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>8/8/2005</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="7438"> 
///
<ExpectedInput>N/A</ExpectedInput>
///
<ExpectedOutput>N/A</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="7439"> 
///
<ExpectedInput>N/A</ExpectedInput>
///
<ExpectedOutput>N/A</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Generate and print report
/// Used by VbecsConsoleReport application
/// </summary>
public override void GenerateAndPrintReport()
va.med.vbecs.reports.CostAccountingReport.CostAccountingReport report = this.GenerateReport(new BOL.VbecsUser(this.PrintedBy).UserName);
report.PrintOptions.PrinterName = this.PrinterName;
report.PrintToPrinter(1, false, 0, 0);
