using System;
using TABLES = EXT.DOMAIN.vbecs.Common.VbecsTables;
using ARTIFICIAL = EXT.DOMAIN.vbecs.Common.DatabaseConstants.ArtificialColumnNames;
namespace EXT.DOMAIN.vbecs.BOL
/// <summary>
/// Summary description for Lock.
/// </summary>
public class Lock
#region Variables 
private System.Guid _recordGuid = System.Guid.Empty;
private System.Guid _formInstanceGuid = System.Guid.Empty;
private System.Guid _sessionGuid = System.Guid.Empty;
private string _userNTLoginId = string.Empty;
private static BOL.VbecsUser _lockUser = null;
private Common.LockFunctions _lockFunction = Common.LockFunctions.NA;
private System.DateTime _lockCreatedTime = System.DateTime.MinValue;
/// <summary>
/// This is populated from a LockInsert.  True = Error.  A lock already existed for this record
/// </summary>
private bool _lockConflictIndicator = false;
//By default, we're creating a lock object, because a lock exists
private bool _lockExists = true;
#endregion
#region Constructors
/// <summary>
/// Default constructor -- I know we're not supposed to, but still need it for data
/// I protected it!
/// </summary>
internal Lock()
this._lockExists = false;
//This constructor should only get called if no locks were found, so we set to false
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>3/3/2005</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="6783"> 
///
<ExpectedInput>Valid DataRow</ExpectedInput>
///
<ExpectedOutput>Lock Object</ExpectedOutput>
///
</Case>
///
///
///<Case type="1" testid ="6784"> 
///
<ExpectedInput>Invalid DataRow</ExpectedInput>
///
<ExpectedOutput>BusinessObjectException</ExpectedOutput>
///
</Case>
///
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Constructor - passing existing Lock info as datarow
/// </summary>
/// <param name="drLock"></param>
public Lock(System.Data.DataRow drLock)
this.LoadFromDataRow(drLock);
#endregion
#region Methods
/// <summary>
/// Loads the Lock Object with data from the DataRow
/// </summary>
/// <param name="drData"></param>
private void LoadFromDataRow(System.Data.DataRow drData)
if (!drData.Table.Columns.Contains(TABLES.VbecsLock.FormInstanceGuid))
throw new BOL.BusinessObjectException(Common.StrRes.SysErrMsg.Common.RequiredFieldMissing(TABLES.VbecsLock.FormInstanceGuid).ResString);
// Database does not allow nulls for these fields, so no need to check
if (drData.Table.Columns.Contains(TABLES.VbecsLock.FormInstanceGuid))
this._formInstanceGuid = (System.Guid)drData[TABLES.VbecsLock.FormInstanceGuid];
if (drData.Table.Columns.Contains(TABLES.VbecsLock.SessionGuid))
this._sessionGuid = (System.Guid)drData[TABLES.VbecsLock.SessionGuid];
if (drData.Table.Columns.Contains(TABLES.VbecsLock.LastUpdateDate))
this._lockCreatedTime = (System.DateTime)drData[TABLES.VbecsLock.LastUpdateDate];
if (drData.Table.Columns.Contains(TABLES.VbecsLock.FunctionId))
this._lockFunction = (Common.LockFunctions)drData[TABLES.VbecsLock.FunctionId];
if (drData.Table.Columns.Contains(TABLES.VbecsLock.LastUpdateUser))
this._userNTLoginId = drData[TABLES.VbecsLock.LastUpdateUser].ToString();
if (drData.Table.Columns.Contains(TABLES.VbecsLock.RecordGuid))
this._recordGuid = (System.Guid)drData[TABLES.VbecsLock.RecordGuid];
if (drData.Table.Columns.Contains(ARTIFICIAL.LockConflictIndicator))
this._lockConflictIndicator = (bool)drData[ARTIFICIAL.LockConflictIndicator];
#endregion
#region Properties
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>3/3/2005</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="6785"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>boolean</ExpectedOutput>
///
</Case>
///
///
///<Case type="1" testid ="6786"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Does the lock exist --- this is for UI for code readablility
/// </summary>
public bool LockExists
get
return(this._lockExists);
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>3/3/2005</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="6787"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>bool</ExpectedOutput>
///
</Case>
///
///
///<Case type="1" testid ="6788"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// When trying to lock a locked record, this will be set to TRUE
/// </summary>
public bool LockConflictIndicator
get
return(this._lockConflictIndicator);
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>3/3/2005</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="6789"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>Guid</ExpectedOutput>
///
</Case>
///
///
///<Case type="1" testid ="6790"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Record being locked
/// </summary>
public System.Guid RecordGuid
get
return(this._recordGuid);
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>3/3/2005</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="6791"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>Guid</ExpectedOutput>
///
</Case>
///
///
///<Case type="1" testid ="6792"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Unique Identifier of the locking form (needed for UC's that can be OMT)
/// OMT = Opened Multiple Times
/// </summary>
public System.Guid FormInstanceGuid
get
return(this._formInstanceGuid);
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>1/24/2007</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="8468"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>Guid</ExpectedOutput>
///
</Case>
///
///
///<Case type="1" testid ="8469"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Returns the SessionGuid that was retrieved from the database (vis #ctr(DataRow)
/// The current value is in Common.LogonUser
/// </summary>
public System.Guid SessionGuid
get
return(this._sessionGuid);
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>3/3/2005</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="6793"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>string</ExpectedOutput>
///
</Case>
///
///
///<Case type="1" testid ="6794"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// NT Id of the locking user
/// </summary>
public string UserNTLoginId
get
return(this._userNTLoginId);
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>3/3/2005</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="6795"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>string</ExpectedOutput>
///
</Case>
///
///
///<Case type="1" testid ="6796"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// User's actual "name" - for displaying messages
/// </summary>
public string UserName
get
//_lockUser is static to avoid creating multiple users over and over
if (_lockUser == null)
_lockUser = new BOL.VbecsUser(this.UserNTLoginId, false);
//If the current user is different than who has the lock
if (_lockUser.UserNTLoginID != this.UserNTLoginId)
_lockUser = new BOL.VbecsUser(this.UserNTLoginId, false);
return(_lockUser.UserName);
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>3/3/2005</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="6797"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>DateTime</ExpectedOutput>
///
</Case>
///
///
///<Case type="1" testid ="6798"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Time the lock was generated
/// </summary>
public System.DateTime LockCreatedTime
get
return(this._lockCreatedTime);
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>3/3/2005</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="6799"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>LockFunctions</ExpectedOutput>
///
</Case>
///
///
///<Case type="1" testid ="6800"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// UC the lock is for
/// </summary>
public Common.LockFunctions LockFunction
get
return(this._lockFunction);
#endregion
