using System;
using System.Data;
using EXT.DOMAIN.vbecs.DAL;
using EXT.DOMAIN.vbecs.ExceptionManagement;
using EXT.DOMAIN.vbecs.Common;
using VBECSLOCK = EXT.DOMAIN.vbecs.Common.VbecsTables.VbecsLock;
namespace EXT.DOMAIN.vbecs.BOL
/// <summary>
/// Summary description for LockManager.
/// </summary>
public class LockManager
/// <summary>
/// Default lock timeout in minutes.
/// </summary>
public const int DefaultLockInactivityTimeoutMin = 5;
private static System.Guid _uc33Guid = new System.Guid("9ED8D1F7-A22C-4F45-9232-47A65798532F");
private static System.Guid _uc34Guid = new System.Guid("3C94FC0E-227A-461B-AAD8-9FB263908762");
private static System.Guid _uc58Guid = new System.Guid("A4776522-CA8F-409F-A640-FAE0D222052E");
private static System.Guid _uc23Guid = new System.Guid("D24122BD-52EE-4641-B24F-452C0A750622");
private static System.Guid _uc38Guid = new System.Guid("4A6A821B-CDDE-42BD-ADAB-5752A14054B0");
// CR 2959
private static Guid _uc69Guid = new Guid("94321A19-E9AE-447E-8BD5-5B723380C95A");
#region Variables
private System.Collections.ArrayList _locks;
#endregion
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>3/3/2005</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="6805"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>LockManager object</ExpectedOutput>
///
</Case>
///
///
///<Case type="1" testid ="6806"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
/// <summary>
/// Blank Constructor - Initializes our Locks Collection
/// </summary>
public LockManager()
this._locks = new System.Collections.ArrayList();
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>3/3/2005</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="6807"> 
///
<ExpectedInput>Valid Record Guid</ExpectedInput>
///
<ExpectedOutput>true, Lock object</ExpectedOutput>
///
</Case>
///
///
///<Case type="1" testid ="6808"> 
///
<ExpectedInput>Invalid Record Guid</ExpectedInput>
///
<ExpectedOutput>false, null</ExpectedOutput>
///
</Case>
///
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Returns if the Record is Already Locked by the UC
/// If it wasn't, any existing locks will get picked up when the lock attempt is
/// performed.  This is a way to try and save DB calls
/// </summary>
/// <param name="recordGuid"></param>
/// <param name="foundLock">Returns</param>
/// <returns></returns>
public bool IsRecordAlreadyLockedInUC(System.Guid recordGuid, out BOL.Lock foundLock)
bool hasRecord = false;
BOL.Lock tmpLock = null;
for (int x=0; x < this._locks.Count; x++)
tmpLock = (BOL.Lock)this._locks[x];
if (tmpLock.RecordGuid == recordGuid)
hasRecord = true;
break;
foundLock = tmpLock;
return(hasRecord);
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>3/3/2005</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="6809"> 
///
<ExpectedInput>RecordGuid</ExpectedInput>
///
<ExpectedOutput>Lock object</ExpectedOutput>
///
</Case>
///
///
///<Case type="1" testid ="6810"> 
///
<ExpectedInput>Invalid Guid</ExpectedInput>
///
<ExpectedOutput>Empty Lock object</ExpectedOutput>
///
</Case>
///
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Returns the UserId of the person who has the lock
/// </summary>
/// <param name="recordGuid"></param>
/// <param name="setLockConflict">Always set this to FALSE, except for ExceptionHandle in Insert</param>
/// <returns></returns>
public static BOL.Lock GetLock(System.Guid recordGuid, bool setLockConflict)
DataTable dtUser = DAL.LockManager.GetLock(recordGuid);
if (dtUser.Rows.Count == 0)
return(new BOL.Lock());
else
if (setLockConflict)
dtUser.Columns.Add(Common.DatabaseConstants.ArtificialColumnNames.LockConflictIndicator, typeof(bool));
dtUser.Rows[0][Common.DatabaseConstants.ArtificialColumnNames.LockConflictIndicator] = true;
return(new BOL.Lock(dtUser.Rows[0]));
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>1/24/2007</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="8470"> 
///
<ExpectedInput>Form Guid</ExpectedInput>
///
<ExpectedOutput>Arraylist containing Locked records</ExpectedOutput>
///
</Case>
///
///
///<Case type="1" testid ="8471"> 
///
<ExpectedInput>Invalid Form Guid</ExpectedInput>
///
<ExpectedOutput>Empty Arraylist</ExpectedOutput>
///
</Case>
///
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Returns an arraylist of BOL.Lock objects for a given FormInstanceGuid
/// </summary>
/// <param name="formInstanceGuid"></param>
/// <returns></returns>
public static System.Collections.ArrayList GetLocksByForm(System.Guid formInstanceGuid)
System.Collections.ArrayList alLocks = new System.Collections.ArrayList();
DataTable dtLocks = DAL.LockManager.GetLocksByFormInstanceGuid(formInstanceGuid);
if (dtLocks.Rows.Count > 0)
foreach(System.Data.DataRow drLock in dtLocks.Rows)
alLocks.Add(new BOL.Lock(drLock));
return(alLocks);
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>3/3/2005</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="6811"> 
///
<ExpectedInput>RecordGuid, FormInstanceGuid, LockFunctions</ExpectedInput>
///
<ExpectedOutput>Lock object</ExpectedOutput>
///
</Case>
///
///
///<Case type="1" testid ="6812"> 
///
<ExpectedInput>Duplicate RecordGuid, FormInstanceGuid, LockFunctions</ExpectedInput>
///
<ExpectedOutput>BusinessObjectException</ExpectedOutput>
///
</Case>
///
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Attempts to lock the supplied record if it's not 
/// </summary>
/// <param name="recordGuid"></param>
/// <param name="formInstanceGuid"></param>
/// <param name="lockFunction"></param>
///<param name="multiDivisionIndicator">Does the record lock span multi divisions (MUC03)</param>
/// <returns></returns>
public BOL.Lock LockRecord(System.Guid recordGuid, System.Guid formInstanceGuid, Common.LockFunctions lockFunction, bool multiDivisionIndicator)
try
System.Data.DataTable dtLock = DAL.LockManager.LockRecord(recordGuid, formInstanceGuid, lockFunction, multiDivisionIndicator);
if (dtLock.Rows.Count == 0)
throw new BOL.BusinessObjectException("No locking information returned!");
if (dtLock.Rows.Count > 1)
throw new BOL.BusinessObjectException("Locking returned too many rows?");
BOL.Lock tmpLock = new BOL.Lock(dtLock.Rows[0]);
//Add the lock to the collection if it was a valid lock
if (!tmpLock.LockConflictIndicator)
this.AddLock(tmpLock);
return(tmpLock);
catch(System.Data.SqlClient.SqlException err)
if (err.Number == 2627)
//Insert conflict, Record Locked for RecordGuid/Division, this 
//should cover simultaneous lock conflicts
BOL.Lock tmpLock = BOL.LockManager.GetLock(recordGuid,true);
return(tmpLock);
else
throw;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>3/3/2005</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="6813"> 
///
<ExpectedInput>RecordGuid, FormInstanceGuid, LockFunctions</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///
///<Case type="1" testid ="6814"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Attempts to unlock the supplied records
/// </summary>
/// <param name="recordGuids"></param>
/// <param name="formInstanceGuid"></param>
/// <param name="lockFunction"></param>
public void UnlockRecords(System.Guid[] recordGuids, System.Guid formInstanceGuid, Common.LockFunctions lockFunction)
//Remove them from the database first...
DAL.LockManager.UnlockRecords(recordGuids, formInstanceGuid, lockFunction );
//Now, remove the lock from the collection
foreach(System.Guid recordGuid in recordGuids)
this.RemoveLock(recordGuid, formInstanceGuid, lockFunction);
/// <summary>
/// Adds a BOL.Lock object to our Lock connection - DB trip saving tool
/// </summary>
/// <param name="addingLock"></param>
private void AddLock(BOL.Lock addingLock)
BOL.Lock tmpLock;
// Justin Case
if (this.IsRecordAlreadyLockedInUC(addingLock.RecordGuid, out tmpLock))
return;
this._locks.Add(addingLock);
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>9/12/2005</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="8211"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>int</ExpectedOutput>
///
</Case>
///
///
///<Case type="1" testid ="8212"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Locked records Count
/// </summary>
public int LockCount
get
if (this._locks == null) 
return(0);
else
return(this._locks.Count);
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>11/16/2005</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="8349"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>Guid</ExpectedOutput>
///
</Case>
///
///
///<Case type="1" testid ="8350"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
/// <summary>
/// Guid to represent a Entire UC lock for UC_34.  This will be the RecordGuid on the VbecsLock table.
/// </summary>
public static System.Guid UC34Guid
get
return _uc34Guid;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>3/28/2006</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="8424"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>Guid</ExpectedOutput>
///
</Case>
///
///
///<Case type="1" testid ="8425"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Guid to represent a Entire UC lock for UC_33.  This will be the RecordGuid on the VbecsLock table.
/// </summary>
public static System.Guid UC33Guid
get
return _uc33Guid;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>2/22/2006</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="8400"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>Guid</ExpectedOutput>
///
</Case>
///
///
///<Case type="1" testid ="8401"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// UC38 Guid
/// </summary>
public static System.Guid UC38Guid
get
return _uc38Guid;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>1/26/2006</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="8383"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>Guid</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="8384"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Guid to represent a Entire UC lock for UC_23.  This will be the RecordGuid on the VbecsLock table.
/// </summary>
public static System.Guid UC23Guid
get
return _uc23Guid;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>1/9/2006</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="8377"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>Guid</ExpectedOutput>
///
</Case>
///
///
///<Case type="1" testid ="8378"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
/// <summary>
/// UC58Guid
/// </summary>
public static System.Guid UC58Guid
get
return _uc58Guid;
/// <summary>
/// Removes a BOL.Lock object from our Lock connection
/// </summary>
/// <param name="recordGuid"></param>
/// <param name="formInstanceGuid"></param>
/// <param name="lockFunction"></param>
private void RemoveLock(System.Guid recordGuid, System.Guid formInstanceGuid, Common.LockFunctions lockFunction)
foreach(BOL.Lock insertedLocks in this._locks)
if (insertedLocks.RecordGuid == recordGuid &&
insertedLocks.LockFunction == lockFunction &&
insertedLocks.FormInstanceGuid == formInstanceGuid )
this._locks.Remove(insertedLocks);
break;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>3/3/2005</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="6815"> 
///
<ExpectedInput>LockFunction, FormInstanceGuid</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///
///<Case type="1" testid ="6816"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Unlocks all records for a Use-Case, FormInstance
/// </summary>
/// <param name="lockFunction"></param>
/// <param name="formInstanceGuid"></param>
public void UnlockAllRecordsForUseCaseUser(Common.LockFunctions lockFunction, System.Guid formInstanceGuid)
DAL.LockManager.UnlockAllRecordsForUseCaseUser(Common.LogonUser.LogonUserName, lockFunction, formInstanceGuid);
this._locks.Clear();
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>9/6/2004</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="1781"> 
///
<ExpectedInput>UserName</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="1782"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
/// <summary>
/// Removes all locks for a particular user
/// </summary>
/// <param name="userName"></param>
/// <param name="unlockAllSessions"></param>
public static void UnlockAllRecordsForUser(string userName, bool unlockAllSessions)
DAL.LockManager.UnlockAllRecordsForUser(userName, unlockAllSessions);
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>3/16/2011</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="9176"> 
///
<ExpectedInput>Valid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="9177"> 
///
<ExpectedInput>Invalid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Guid to represent a Entire UC lock for UC_69.  This will be the RecordGuid on the VbecsLock table.
/// </summary>
public static System.Guid UC69Guid
get
return _uc69Guid;
