using System.Data;
using System.Net;
using System.Reflection;
using EXT.DOMAIN.vbecs.Common;
using BrRules = EXT.DOMAIN.vbecs.Common.VbecsBrokenRules.VistaLinkConfig;
using VistALinkControlTable = EXT.DOMAIN.vbecs.Common.VbecsTables.VistaLinkControl;
using EXT.DOMAIN.vbecs.DAL.VistALink.OpenLibrary;
namespace EXT.DOMAIN.vbecs.BOL
#region Header
///<Package>Package: VBECS - VistA Blood Establishment Computer System</Package>
///<Warning> WARNING: Per VHA Directive $VADIRECTIVE this class should not be modified</Warning>
///<MedicalDevice> Medical Device #: $MEDDEVICENO</MedicalDevice>
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>9/17/2004</CreationDate>
///<Note>The Food and Drug Administration classifies this software as a medical device.  As such, it may not be changed in any way. Modifications to this software may result in an adulterated medical device under 21CFR820, the use of which is considered to be a violation of US Federal Statutes.  Acquiring and implementing this software through the Freedom of information Act requires the implementor to assume total responsibility for the software, and become a registered manufacturer of a medical device, subject to FDA regulations</Note>
///<summary>
///
Container for VBECS' VistALink configuration parameters. Provides validation, retrieve/update 
///
capabilities and conversion to VistALink native connection info type.
///</summary>
#endregion
public class VistALinkConfig : BaseBusinessObject
private const int MinTcpPortNumber = 1024;
private const int MaxTcpPortNumber = 65535;
private IPAddress _vistaIpAddress;
private string _vistaDomainName;
private int _vistaTcpPort;
private const string PrimaryServerHandle = "Primary";
private const string PrimaryServerAlias = "Primary VBECS-connected VistA System";
/// <summary>
/// Constructs fresh instance of the class.
/// </summary>
private VistALinkConfig()
SetInitialBrokenRules( BrRules.FormClassName, BrRules.RuleSets.BaseRuleSet );
this.VistaPortNumber = StNullConvert.Int32Null;
this.VistaIpAddress = null;
this.VistaDomainName = null;
this.IsNew = true;
this.IsDirty = false;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>9/17/2004</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="5585"> 
///
<ExpectedInput>None, VistALink configuration is defined in the DB.</ExpectedInput>
///
<ExpectedOutput>Object initialized with non-null values from DB and not marked as new, no BRs are broken.</ExpectedOutput>
///
</Case>
///
///<Case type="0" testid ="5591"> 
///
<ExpectedInput>None, VistALink configuration is not defined in the DB (fresh install).</ExpectedInput>
///
<ExpectedOutput>Object is empty, marked as new, 2 BRs are broken.</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="5586"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Gets current VistALink configuration by retrieving it from DB or 
/// constructing a fresh object if there's no configuration available in the DB.
/// </summary>
/// <returns>An instance of VistALink config representing current VistALink configuration.</returns>
public static VistALinkConfig GetCurrent()
VistALinkConfig _resultConfig = new VistALinkConfig();
DataRow _currentValues = DAL.VistALinkConfig.Load( PrimaryServerHandle );
if( _currentValues != null )
_resultConfig.LoadFromDataRow( _currentValues );
return _resultConfig;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>9/17/2004</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="5583"> 
///
<ExpectedInput>Valid DataRow, object is valid.</ExpectedInput>
///
<ExpectedOutput>Data is loaded into the supplied DataRow.</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="5584"> 
///
<ExpectedInput>Null.</ExpectedInput>
///
<ExpectedOutput>ArgumentNullException</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="5592"> 
///
<ExpectedInput>Valid DataRow, but object is invalid.</ExpectedInput>
///
<ExpectedOutput>BusinessObjectException</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Loads data from this instance of the class into a supplied <see cref="DataRow"/>.
/// </summary>
/// <param name="dtRow"><see cref="DataRow"/> to load data into.</param>
/// <returns>Reference to provided <see cref="DataRow"/>.</returns>
public override DataRow LoadDataRowFromThis( DataRow dtRow )
if( !IsValid ) 
throw( new BusinessObjectException( StrRes.SysErrMsg.Common.UnableToSaveInvalidBusinessObject( typeof( VistALinkConfig ).Name ).ResString ) );
Utility.RequireColumns( dtRow, VistALinkControlTable.ServerAppHandle, VistALinkControlTable.ServerAlias, VistALinkControlTable.VistaPortNumber, VistALinkControlTable.RowVersion );
dtRow[ VistALinkControlTable.ServerAppHandle ] = StDbNullConvert.From( PrimaryServerHandle );
dtRow[ VistALinkControlTable.ServerAlias ] = StDbNullConvert.From( PrimaryServerAlias );
dtRow[ VistALinkControlTable.VistaIpAddress ] = StDbNullConvert.From( this.VistaIpAddress );
dtRow[ VistALinkControlTable.VistaDomainName ] = StDbNullConvert.From( this.VistaDomainName );
dtRow[ VistALinkControlTable.VistaPortNumber ] = StDbNullConvert.From( this.VistaPortNumber );
dtRow[ VistALinkControlTable.RowVersion ] = StDbNullConvert.From( this.RowVersion );
return dtRow;
/// <summary>
/// Loads data into this instance of the class from a supplied <see cref="DataRow"/>.
/// </summary>
/// <param name="dtRow"><see cref="DataRow"/> to load data from.</param>
protected override void LoadFromDataRow( DataRow dtRow )
Utility.RequireNonNullColumns( dtRow, VistALinkControlTable.VistaPortNumber, VistALinkControlTable.RowVersion );
this.VistaIpAddress = StDbNullConvert.ToIPAddress( dtRow[ VistALinkControlTable.VistaIpAddress ] );
this.VistaDomainName = StDbNullConvert.ToString( dtRow[ VistALinkControlTable.VistaDomainName ] );
this.VistaPortNumber = StDbNullConvert.ToInt32( dtRow[ VistALinkControlTable.VistaPortNumber ] );
this.RowVersion = StDbNullConvert.ToRowversion( dtRow[ VistALinkControlTable.RowVersion ] );
if( !IsValid )
throw( new BusinessObjectException( StrRes.SysErrMsg.Common.InvalidDataLoadedFromDataRowIntoBusinessObject( typeof( VistALinkConfig ).Name, MethodBase.GetCurrentMethod().Name ).ResString ) );
this.IsNew = false;
this.IsDirty = false;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>9/17/2004</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="5581"> 
///
<ExpectedInput>Update function, object is valid and config already exists in the DB.</ExpectedInput>
///
<ExpectedOutput>Object data is saved to the DB, object is not new and dirty.</ExpectedOutput>
///
</Case>
///
///<Case type="0" testid ="5593"> 
///
<ExpectedInput>Update function, object is valid and config is not in the DB yet.</ExpectedInput>
///
<ExpectedOutput>Object data is saved to the DB, object is not new and dirty.</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="5582"> 
///
<ExpectedInput>Update function, object is not valid (BRs are broken).</ExpectedInput>
///
<ExpectedOutput>BusinessObjectException.</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Saves server connection info to the database.
/// </summary>
///
<param name="updateFunction">Update function.</param>
public virtual void Save( UpdateFunction updateFunction )
DataRow _bufferRow = DAL.VistALinkConfig.GetVistaLinkControlEmptyDataTable().NewRow();
LoadDataRowFromThis( _bufferRow );
_bufferRow[ VistALinkControlTable.LastUpdateFunctionId ] = (int)updateFunction;
DAL.VistALinkConfig.Save( _bufferRow );
IsNew = false;
IsDirty = false;
/// <summary>
/// Triggered whenever any significant object property is changed.
/// </summary>
protected virtual void OnPropertyChanged()
this.IsDirty = true;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>9/17/2004</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="5579"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>Server connection info object.</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="5580"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Converts the connection parameters to VistALink native <see cref="ServerConnectionInfo"/> data type.
/// </summary>
/// <returns>New instance of <see cref="ServerConnectionInfo"/> containing VistALink connection parameters.</returns>
public virtual ServerConnectionInfo GetServerConnectionInfo()
if( !IsValid ) 
throw( new BusinessObjectException( StrRes.SysErrMsg.Common.UnableToExportVistALinkConfigurationFromBO( this.GetType().Name ).ResString ) );
return new ServerConnectionInfo( PrimaryServerHandle, PrimaryServerAlias, _vistaIpAddress, _vistaDomainName, _vistaTcpPort );
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>9/17/2004</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="5577"> 
///
<ExpectedInput>Valid IP address.</ExpectedInput>
///
<ExpectedOutput>No rules are broken, value is assigned, object marked dirty.</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="5594"> 
///
<ExpectedInput>Null value.</ExpectedInput>
///
<ExpectedOutput>Corresponding rule is broken, object marked dirty.</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// VistA system IP address.
/// </summary>
public virtual IPAddress VistaIpAddress
get
return _vistaIpAddress;
set
if (_vistaIpAddress == value || ( _vistaIpAddress != null && value != null & _vistaIpAddress.Equals( value ))) return;
_vistaIpAddress = value;
// MBR_1.12 
RuleBroken(BrRules.VistaServerIpAddressAndDomainNameNotSpecified, StNullConvert.IsNull( _vistaIpAddress )&& (_vistaDomainName == null || _vistaDomainName.Trim() == string.Empty));
if( _vistaIpAddress == value || ( _vistaIpAddress != null && value != null & _vistaIpAddress.Equals( value ) ) )
OnPropertyChanged();
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>7/9/2007</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="8492"> 
///
<ExpectedInput>Valid domain name value</ExpectedInput>
///
<ExpectedOutput>No rules are broken, object marked dirty.</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="8493"> 
///
<ExpectedInput>Undefined domain name</ExpectedInput>
///
<ExpectedOutput>Corresponding rule is broken, object marked dirty.</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// VistA M server domain name
/// </summary>
public virtual string VistaDomainName
get
return _vistaDomainName;
set
if (_vistaDomainName == value) return;
_vistaDomainName = value;
// MBR_1.12 
RuleBroken(BrRules.VistaServerIpAddressAndDomainNameNotSpecified, StNullConvert.IsNull( _vistaIpAddress )&& (_vistaDomainName == null || _vistaDomainName.Trim() == string.Empty));
OnPropertyChanged();
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>9/17/2004</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="5575"> 
///
<ExpectedInput>Valid port number value.</ExpectedInput>
///
<ExpectedOutput>No rules are broken, object marked dirty.</ExpectedOutput>
///
</Case>
///
///<Case type="0" testid ="5595"> 
///
<ExpectedInput>Undefined port number.</ExpectedInput>
///
<ExpectedOutput>Corresponding rule is broken, object marked dirty.</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="5576"> 
///
<ExpectedInput>Out-of-range port number.</ExpectedInput>
///
<ExpectedOutput>Corresponding rule is broken, object marked dirty.</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// VistA system TCP port number. 
/// </summary>
public virtual int VistaPortNumber
get
return _vistaTcpPort;
set
if( _vistaTcpPort == value )
return;
_vistaTcpPort = value;
bool _tcpPortIsDefined = !RuleBroken( BrRules.VistaServerPortNumberNotSet, StNullConvert.IsNull( _vistaTcpPort ) );
RuleBroken( BrRules.VistaServerPortNumberOutOfRange, 
_tcpPortIsDefined && ( _vistaTcpPort < MinTcpPortNumber || _vistaTcpPort > MaxTcpPortNumber ) );
OnPropertyChanged();
