using System;
using System.Collections;
using System.Net.Sockets;
using System.Text;
using System.Configuration;
using EXT.DOMAIN.vbecs.Common;
namespace EXT.DOMAIN.vbecs.DAL.HL7.Client.WinService
    /// <summary>
    /// Implementation of IPinger insterface for Vista HL7 pinging. CR 2732.
    /// </summary>
    public class HL7Pinger : IPinger
    {
        string _pingMessage = null;
        string _pingIP = null;
        int _pingPort = 0;
/// <summary>
/// Constructor. Throws ConfigurationException.
/// </summary>
/// <param name="in_params">Hashtable of input parameters.</param>
        public HL7Pinger(object in_params)
        {
            Hashtable params_table = in_params as Hashtable;
            if(!params_table.Contains("PingIP") || params_table["PingIP"] == null)
                throw new ConfigurationException("HL7 Pinger: PingIP information is not found");
            _pingIP = params_table["PingIP"] as string;
            if(!params_table.Contains("PingMessage") || params_table["PingMessage"] == null)
                throw new ConfigurationException("HL7 Pinger: PingMessage information is not found");
            _pingMessage = params_table["PingMessage"] as string;
            if(!params_table.Contains("PingPort") || params_table["PingPort"] == null)
                throw new ConfigurationException("HL7 Pinger: PingPort information is not found");
            try
            { _pingPort = int.Parse( params_table["PingPort"] as string ); }
            catch(Exception ex)
            { throw new ConfigurationException("HL7 Pinger: Can't parse port numner", ex); }
        }
/// <summary>
/// Called on timed manner regarding services' configuration.
/// </summary>
        public void Ping()
        {
            do_ping();
        }
        /// <summary>
        /// Connects to HL7 Listener Service and sends/receives a VistA HL7 PING message.
        /// Open new connect every time. It is OK since usual ping times are about 1 hour.
        /// </summary>
        protected void do_ping()
        {
            string _forciblyClosed = "An existing connection was forcibly closed by the remote host";
            try
            {
                using(TcpClient client = new TcpClient())
                {
                    client.NoDelay = true;
                    client.SendTimeout = 2;
                    client.Connect( _pingIP, _pingPort );
                    using(NetworkStream stream = client.GetStream())
                    {
                        string pingMessage = string.Concat( _pingMessage, DateTime.Now.ToLongTimeString() );
                        StringBuilder confMsg = new StringBuilder();
                        byte[] dataChunk = ToByteArray(pingMessage);
                        if(!stream.CanWrite)
                            throw new ApplicationException("Pinger: can't write data into the stream");
                        // Send PING message
                        stream.Write( dataChunk, 0, dataChunk.Length );
                        if(!stream.CanRead)
                            throw new ApplicationException("Pinger: can't read data into the stream");
                        byte[] bytes = new byte[dataChunk.Length];
                        int bytesRead = 0;
                        // Just read the stream and add the characters to the StringBuilder.
                        // Actually, the StringBuilder probably isn't necessary.
                        bytesRead = stream.Read(bytes, 0, bytes.Length);
                        confMsg.Append(Encoding.ASCII.GetChars(bytes));
                        // Check that the bytes returned contain the pingMessage.
                        // There are additional control characters added to the end of the stream,
                        // but we don't care about that, so we just check if the first part
                        // of the message is the same as the original Ping message.
                        if( confMsg.ToString().Substring(0,pingMessage.Length) != pingMessage )
                            throw new ApplicationException(string.Format("Pinger: incorrect responce from HL7 service [{0}]", confMsg.ToString().Substring(0,pingMessage.Length)));
                    }
                }
            }
            catch(System.IO.IOException ex)
            {
                // We ignore the 'forcibly closed' IO exceptions; throw the rest
                if( ex.ToString().IndexOf( _forciblyClosed ) == -1 )
                    throw;
            }
        }
        /// <summary>
        /// Serializes message and packs it to byte array.
        /// </summary>
        /// <returns>HL7 message packed to byte array.</returns>
        private byte[] ToByteArray(string pingMessage)
        {
            return ToByteArray( pingMessage, System.Xml.Formatting.None );
        }
        private byte[] ToByteArray( string pingMessage, System.Xml.Formatting format )
        {
            System.IO.MemoryStream _stream = new System.IO.MemoryStream();
            System.IO.StreamWriter _writer = new System.IO.StreamWriter( _stream, Encoding.ASCII );
            _writer.Write("\x0B");
            _writer.Write(pingMessage);
            _writer.Write("\x1C");
            _writer.Write("\x0D");
            _writer.Flush();
            _writer.Close();
            return _stream.ToArray();
        }
    }
