using System;
using System.Configuration;
using System.ServiceProcess;
using System.Threading;
using System.Reflection;
using EXT.DOMAIN.vbecs.Common;
namespace EXT.DOMAIN.vbecs.DAL.HL7.Client.WinService
/// <summary>
/// Resposible for pinging job. Created regarding CR 2732.
/// </summary>
    public class TimerService : System.ServiceProcess.ServiceBase
    {
        private bool log_ = false;
        private int ping_interval_ = 0;
        private bool enabled_ = false;
        IPinger pinger_ = null;
        private Thread ping_thread_ = null;
        object sync_ = new object();
        private volatile bool stopping_ = false;
        private volatile bool failed_ = false;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>7/16/2010</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="8977"> 
///
<ExpectedInput>Valid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="8978"> 
///
<ExpectedInput>Invalid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Constructor
/// </summary>
        public TimerService()
        {
        }
/// <summary>
/// Called when services starts
/// </summary>
/// <param name="args"></param>
        protected override void OnStart(string[] args)
        {
// Probably it would be more logical to create pinger object at constructor.
// But app.configuration file is being updated in the ProjectIstaller and it is not ready by that time.
// So read configuration and create pinget on service start event.
TimerSettingsSection timer_conf = (TimerSettingsSection)System.Configuration.ConfigurationSettings.GetConfig("TimerGroup/TimerSettings");
enabled_ = timer_conf.Enabled;
if(!enabled_)
return;
log_ = timer_conf.Log;
ping_interval_ = timer_conf.PingInterval;
// Create pinger object
string assembly_name = System.Text.RegularExpressions.Regex.Match(timer_conf.Type, ",\\s(.+)").Groups[1].Value;
string assembly_type = System.Text.RegularExpressions.Regex.Match(timer_conf.Type, "(.+),\\s").Groups[1].Value;
            try
            {
                pinger_ = AppDomain.CurrentDomain.CreateInstanceAndUnwrap(assembly_name, assembly_type, false, BindingFlags.ExactBinding | BindingFlags.Instance | BindingFlags.Public, null, new object[]{ timer_conf.InParams }, null, null, null) as IPinger;
                // Following case probably never will be executed
                if(pinger_ == null)
                    throw new ConfigurationException("Was not able to created Pinger object ["+ timer_conf.Type +"]");
            }
            catch(TargetInvocationException ex)
            {
                // Suspend only ConfigurationException exceptions.
                if(!(ex.InnerException is ConfigurationException))
                    throw;
                EventsLoggerSingleton.Instance.Log("Can't create HL7 Pinger [" + ex.InnerException + "]. Pinger job is disabled."); 
                enabled_ = false;
                return;
            }
            //start worker thread
            ping_thread_ = new Thread( new ThreadStart( BlockingStart ) );
            ping_thread_.Start();
        }
/// <summary>
/// Called when service stops
/// </summary>
        protected override void OnStop()
        {
            if(!enabled_ || ping_thread_ == null)
                return;
            //stop worker thread
            do_stop_worker_thread();
        }
        // For VBECS services ping thread shoud be wrapped by try/catch so we will be sure
        // that this service will never generate exception.
        // After we will use currentDomain_UnhandledException in VBECS listeners it will not be necessary.
        private void BlockingStart()
        {
            try
            {
                //int i = 0;
                while(true)
                {
                    lock(sync_) 
                    {
                        if(stopping_) 
                            return;
                        //Waits for X ms unless a stop event occures.
                        Monitor.Wait(sync_, ping_interval_ * 1000); 
                        if(stopping_) 
                            return;
                        if(log_)
                            EventsLoggerSingleton.Instance.Log("Timer Tick");
                        // Call pinger method
                        if(pinger_ != null)
                        {
                            try
                            {
                                // Ping doesn't return any information.
                                // In case of error it throws exception
                                pinger_.Ping();
                            }
                            catch(Exception ex1)
                            {
if(stopping_ || ex1 == null) 
return;
                                //If ping failed first time, try to reping in one minute:
Monitor.Wait(sync_, 60 * 1000); 
if(stopping_) 
return;
try
pinger_.Ping();
catch(Exception ex)
EventsLoggerSingleton.Instance.Log("CPRS Ping failed [" + ex.Message + "]"); 
                            }
                        }
                        //if(i++ == 2)
                        //    throw new ApplicationException("test");
                    }
                }
            }
            catch(Exception ex)
            {
                lock(sync_) 
                {
                    // Flag that ping thread has failed
                    failed_ = true;
                } 
                EventsLoggerSingleton.Instance.Log("Ping thread failed [" + ex.Message + "]"); 
                throw;
            }
        }
/// <summary>
/// Stops thread execution
/// </summary>
        protected void do_stop_worker_thread()
        {
            lock(sync_) 
            {
                if(failed_)
                {
                    EventsLoggerSingleton.Instance.Log(this.ServiceName + " ping thread failed and will be stopped by itself");         
                    return;
                }
                stopping_ = true;
                Monitor.Pulse(sync_); //wake up the worker thread.
            }
            //wait for the worker thread to finish to ensure that we've actually stopped before returning.
            ping_thread_.Join();   
            if(log_)
                EventsLoggerSingleton.Instance.Log(this.ServiceName + " ping thread stopped");         
        }
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>7/16/2010</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="8979"> 
///
<ExpectedInput>Valid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="8980"> 
///
<ExpectedInput>Invalid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Timer
/// </summary>
        virtual public void TimerTick()
        {}
    }
