using System;
using System.Configuration;
namespace EXT.DOMAIN.vbecs.Common
    /// <summary>
    /// Simple logger tool. Logs messages to system Events.
    /// Log and Source may be configured in app configuration file.
    /// This is thread safe singleton. It can be used by many modules at the same time.
    /// Configuration is read once for the process at the first instalse call.
    /// 
    /// This is common element that was created in scope of CR2761
    /// </summary>
    public class EventsLoggerSingleton
    {
        private System.Diagnostics.EventLog support_event_log_ = null;
        private System.Diagnostics.EventLog event_log_ = null;
/// <summary>
/// Creates instance of EventsLoggerSingleton class.
/// </summary>
        public EventsLoggerSingleton()
        {
            // Setup support event logger
            // This is backup logger is necessary in case regular logger will fail to log message some reason
            support_event_log_ = new System.Diagnostics.EventLog();
            support_event_log_.Source = "VBECSEventsLogger";
            // Try to read service name from the configuration file
            string service_name = null;
            try { service_name = ConfigurationSettings.AppSettings["serviceName"]; }
            catch{}
            // Read Log information
            string log_name = null;
            try { log_name = ConfigurationSettings.AppSettings["LogName"]; }
            catch{}
            if( log_name == null )
              log_name = "Application"; //default falue
            string log_source = null;
            try { log_source = ConfigurationSettings.AppSettings["LogSource"]; }
            catch{}
            // Default value for log source is VBECS 
            if(log_source == null && service_name == null)
              log_source = "VBECS";
            event_log_ = new System.Diagnostics.EventLog();
            // For services: if log source is not specifyed we use regular log source (which is used by OS by default) = ServiceName.
            // log_name in the case will be ignored since it is not possible since default log source is already defined in the Application log.
            if(log_source == null || log_source == service_name)
            {
                event_log_.Source = service_name;
                return;
            }
            // Use custom log and source
            if(!System.Diagnostics.EventLog.SourceExists(log_source))
                System.Diagnostics.EventLog.CreateEventSource(log_source, log_name);
            event_log_.Source = log_source;
            event_log_.Log = log_name;
        }
/// <summary>
/// Function logs message to the system's events
/// </summary>
/// <param name="message">string message that need to b elogged</param>
        public virtual void Log(string message)
        {
            this.Log(message, System.Diagnostics.EventLogEntryType.Information);
        }
        /// <summary>
        /// Function logs message to the system's events
        /// </summary>
        /// <param name="message">string message that need to be logged</param>
        /// <param name="type">events log enty type</param>
        public virtual void Log(string message, System.Diagnostics.EventLogEntryType type)
        {
          try
          {
            event_log_.WriteEntry(message, type);
          }
          catch
          {
            support_event_log_.WriteEntry(message, System.Diagnostics.EventLogEntryType.Error);
          }
        }
/// <summary>
/// Returns instance of EventsLoggerSingleton class
/// </summary>
public static EventsLoggerSingleton Instance
        {
            get
            {
                return Nested.instance;
            }
        }
        class Nested
        {
            // Explicit static constructor to tell C# compiler
            // not to mark type as beforefieldinit
            static Nested()
            {
            }
            internal static readonly EventsLoggerSingleton instance = new EventsLoggerSingleton();
        }
    }
