#region References
using System;
using System.Data.SqlClient;
using System.Collections;
using System.Threading;
using System.IO;
using System.Net;
using System.Net.Sockets;
using System.Diagnostics;
using System.Configuration;
using System.ServiceProcess;
using System.Text;
using System.Reflection;
using System.Xml;
using Microsoft.Win32;
using EXT.DOMAIN.vbecs.Common;
using EXT.DOMAIN.vbecs.DAL.HL7AL;
using EXT.DOMAIN.vbecs.DAL.HL7.OpenLibrary;
using EXT.DOMAIN.vbecs.DAL.HL7.OpenLibrary.Messages;
#endregion
namespace EXT.DOMAIN.vbecs.DAL.HL7.Listener.Core
#region Header
//<Package>Package: VBECS - VistA Blood Establishment Computer System</Package>
//<Warning> WARNING: Per VHA Directive $VADIRECTIVE this class should not be modified</Warning>
//<MedicalDevice> Medical Device #: $MEDDEVICENO</MedicalDevice>
//<Developers>
//
<Developer></Developer>
//</Developers>
//<SiteName>Hines OIFO</SiteName>
//<CreationDate>5/10/2004</CreationDate>
//<Note>The Food and Drug Administration classifies this software as a medical device.  As such, it may not be changed in any way. Modifications to this software may result in an adulterated medical device under 21CFR820, the use of which is considered to be a violation of US Federal Statutes.  Acquiring and implementing this software through the Freedom of information Act requires the implementor to assume total responsibility for the software, and become a registered manufacturer of a medical device, subject to FDA regulations</Note>
//<summary>The SimpleListener is a basic TCP/IP port listener base type that is designed to be implemented by a VBECS HL7 interface listener Windows Service.</summary>
#endregion
/// <summary>
/// Class SimpleListener
/// </summary>
public abstract class SimpleListener
#region ClientRequestContext
/// <summary>
/// Constructor
/// </summary>
private sealed class ClientRequestContext
#region Variables
private const string BCE_COTS_INTERFACE = "BCE_COTS";
private const string CPRS_INTERFACE = "CPRS";
private const string PATIENT_MERGE_INTERFACE = "Patient_Merge";
private const string PATIENT_UPDATE_INTERFACE = "Patient_Update";
private const string DB_QUERY = "SELECT Top 1 * FROM InterfaceControl";
private const string PRIMARY_DB_CONNECTION_STRING_KEY = "PrimaryDbConnectionString";
private const string SERVICE_NAME_KEY = "serviceName";
private const string UNSUPPORTED_INTERFACE_ERROR = "The Sending and/or Receiving Application(s) in the message are not supported by VBECS in this combination.\n\n";
private string _dbConnectionString;
private string _serviceName;
#endregion
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>2/16/2011</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="9004"> 
///
<ExpectedInput>Valid</ExpectedInput>
///
<ExpectedOutput>N/A</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="9005"> 
///
<ExpectedInput>Invalid</ExpectedInput>
///
<ExpectedOutput>N/A</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Static Constructor, defines the db Connectio string and the service name.
/// </summary>
public ClientRequestContext()
this._dbConnectionString = Convert.ToString( ConfigurationSettings.AppSettings[PRIMARY_DB_CONNECTION_STRING_KEY] );
this._serviceName = Convert.ToString( ConfigurationSettings.AppSettings[SERVICE_NAME_KEY] );
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>7/16/2010</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="9008"> 
///
<ExpectedInput>Valid</ExpectedInput>
///
<ExpectedOutput>N/A</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="9009"> 
///
<ExpectedInput>Invalid</ExpectedInput>
///
<ExpectedOutput>N/A</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// ServeClient
/// </summary>
public void ServeClient( Socket socket, HL7Interface hl7Interface )
if( !socket.Connected )
throw( new HL7Exception("Socket not connected to remote host") );
//
try
string incomingMessage = HL7RRConnection.ReceiveMessage( socket );
//
if( incomingMessage.StartsWith("MSH^PING") )
HL7RRConnection.ReturnPing( incomingMessage, socket );
else
bool errorRetrievingInterface = false;
bool isNonVbecsPatientUpdate = false;
bool isBceUpdate = false; // CR 2940
//
HL7ProtocolMessage ackMessage = null;
//
if( hl7Interface == null )
hl7Interface = GetInterfaceParameters( incomingMessage, ref isNonVbecsPatientUpdate, ref isBceUpdate, ref errorRetrievingInterface );
//
if( errorRetrievingInterface || (hl7Interface == null && !isNonVbecsPatientUpdate) )
// Should never get here unless unsupported interface sends us a message
// or interface definition on sending system is incorrect.
// Addresses CR 2140, CR 2940
// 
ackMessage = HandleUnsupportedInterface( incomingMessage, ((IPEndPoint)socket.RemoteEndPoint).Address.ToString() );
else if( hl7Interface == null && isNonVbecsPatientUpdate ) // CR 2960
ackMessage = HL7AckMessage.BuildAckMessage( incomingMessage, AckCodes.AA, string.Empty );
else if( hl7Interface != null && !(isBceUpdate && !hl7Interface.InterfaceActiveIndicator) ) // CR 2940
// CR 2606, CR 2659
Hashtable errorMessageTable = ValidateVbecsRequiredMessageContent( incomingMessage );
// 
if ( errorMessageTable == null )
ackMessage = SimpleListenerHL7Manager.ProcessIncomingHL7Message( hl7Interface, incomingMessage );
else
ackMessage = HandleUnsupportedPatientName( hl7Interface, incomingMessage, errorMessageTable, ((IPEndPoint)socket.RemoteEndPoint).Address.ToString() );
} 
//
if ( ackMessage != null )
if( (hl7Interface != null && hl7Interface.LogEvents) || hl7Interface == null )
EventsLoggerSingleton.Instance.Log( string.Concat("Response Message: \n\n\n", this._serviceName, " sent message:\n\n", ackMessage.GetMessage()), EventLogEntryType.Information );
//
HL7RRConnection.SendMessage( ackMessage, socket );
} // else: incomingMessage.StartsWith("MSH^PING") == false
catch( Exception xcp )
if( xcp is ThreadAbortException )
throw;
//
if( xcp is IOException || xcp is SocketException )
throw( new HL7Exception( "Network problems prevent communicating with the client", xcp ) );
//
string exceptionMessage = ExceptionManagement.DefaultPublisher.FormatExceptionInfoAndDumpToString(xcp);
//
EventsLoggerSingleton.Instance.Log( exceptionMessage, System.Diagnostics.EventLogEntryType.Error );
//
if( hl7Interface != null )
// Only send mail message if interface parameters are defined to prevent exception.
// Related to CR 2140.
SendMailMessage( exceptionMessage, hl7Interface );
/// <summary>
/// CR 2960
/// CR 3082: updated code to retrieve interface parameters for each new message.
/// </summary>
/// <param name="message"></param>
/// <param name="isNonVbecsPatientUpdate"></param>
/// <param name="isBceUpdate"></param>
/// <param name="errorRetrievingInterface"></param>
/// <returns></returns>
private static HL7Interface GetInterfaceParameters(string message, ref bool isNonVbecsPatientUpdate, ref bool isBceUpdate, ref bool errorRetrievingInterface)
HL7Interface hl7Interface = null;
//
try
if( message == null )
throw( new ArgumentNullException( "message" ) );
//
// This includes field separator in position [0] and encoding characters in [1] - [4]
char [] delimiters = HL7Utility.ParseGetMessageDelimiters(message);
string mshSegment = HL7Utility.ParseGetRequiredMessageSegment( message, SegmentTypeNames.MSH );
string interfaceAppId = HL7Utility.ParseGetSegmentData(mshSegment, delimiters[0].ToString(), 2);
string vbecsAppId = HL7Utility.ParseGetSegmentData(mshSegment, delimiters[0].ToString(), 4);
//
if ( interfaceAppId != null && vbecsAppId != null )
{ 
hl7Interface = HL7Interface.GetInterfaceByApplicationIdentifiers( interfaceAppId, vbecsAppId );
if ( hl7Interface != null )
if ( hl7Interface.InterfaceName == Common.InterfaceName.Patient_Update.ToString() )
string pidSegment = HL7Utility.ParseGetRequiredMessageSegment( message, SegmentTypeNames.PID );
//
// CR 2971
long vistAPatientId = HL7Utility.ParseGetVistAPatientId( pidSegment, delimiters );
//
if ( !HL7AL.PatientChange.IsVbecsPatient(vistAPatientId) )
isNonVbecsPatientUpdate = true;
//
hl7Interface = null;
else if ( hl7Interface.InterfaceName == Common.InterfaceName.BCE_COTS.ToString() )
// CR 2940
isBceUpdate = true;
catch(Exception ex)
errorRetrievingInterface = true;
//
EventsLoggerSingleton.Instance.Log( HL7Utility.GetInnerExceptionFromException(ex), System.Diagnostics.EventLogEntryType.Error );
//
return hl7Interface;
/// <summary>
/// CR 2606
/// </summary>
private HL7ProtocolMessage HandleUnsupportedInterface( string hl7Message, string ipAddress )
HL7ProtocolMessage ackMessage = null;
// 
string errorMesage = "Incorrect or unsupported key identifiers in message. Check HL7 Application Parameters.";
//
ackMessage = HL7AckMessage.BuildAckMessage( hl7Message, AckCodes.AR, errorMesage );
//
RecordUnsupportedHL7MessageErrorDetails( ipAddress, hl7Message, UNSUPPORTED_INTERFACE_ERROR, EventLogEntryType.Warning, null );
//
return ackMessage;
/// <summary>
/// Implements VistA Application Interface Specification: 8.1 (unsupported patient names)
/// CR 2606
/// </summary>
private HL7ProtocolMessage HandleUnsupportedPatientName( HL7Interface hl7Interface, string hl7Message, Hashtable errorMessageTable, string ipAddress )
// **********************************************************************************************
// CR 2606: If patient name length exceeds the max allowed value then write error to event log, 
// email the interface administrator and return an acknowledgement reject (AR) message for the 
// CPRS or Patient Update interfaces and an application accept (AA) message for the Patient Merge 
// interface, which cannot process reject messages at this time
//
HL7ProtocolMessage ackMessage = null;
//
// Changed keys to refer to string constants (which were added for CR 2659)
string acknowledgementErrorMessage = errorMessageTable.ContainsKey(ACKNOWLEDGEMENT_ERROR_MESSAGE_KEY) ? errorMessageTable[ACKNOWLEDGEMENT_ERROR_MESSAGE_KEY].ToString() : string.Empty;  
string detailedErrorMessage = errorMessageTable.ContainsKey(DETAILED_ERROR_MESSAGE_KEY) ? errorMessageTable[DETAILED_ERROR_MESSAGE_KEY].ToString() : string.Empty; 
//
switch( hl7Interface.InterfaceName )
case BCE_COTS_INTERFACE:
case CPRS_INTERFACE:
case PATIENT_UPDATE_INTERFACE:
//HL7OmgMessage message = new HL7OmgMessage( hl7Message );
//ackMessage = CprsOrgMessage.AckError( message, AckCodes.AR, acknowledgementErrorMessage );
ackMessage = HL7AckMessage.BuildAckMessage( hl7Message, AckCodes.AR, acknowledgementErrorMessage );
break;
case PATIENT_MERGE_INTERFACE:
ackMessage = HL7AckMessage.BuildAckMessage( hl7Message, AckCodes.AA, string.Empty );
break;
//
RecordUnsupportedHL7MessageErrorDetails( ipAddress, hl7Message, detailedErrorMessage, EventLogEntryType.Error, hl7Interface );
//
return ackMessage;
/// <summary>
/// Builds and sends an email message and writes to the server event log, warning that an unsupported HL7 message was received.
/// The email is constructed without the full HL7 details; we use the MSH segment as the "ID" so that the recipient can tie 
/// the email message to the full HL7 message, which is recorded in the event log.  
/// CR 2606, CR 2898
/// </summary>
private void RecordUnsupportedHL7MessageErrorDetails( 
string ipAddress, string hl7Message, string errorMessage, EventLogEntryType eventLogEntryType, HL7Interface hl7Interface )
{ 
StringBuilder fullErrorMessageBuilder = new StringBuilder();
//
fullErrorMessageBuilder.Append("The ");
fullErrorMessageBuilder.Append(this._serviceName);
fullErrorMessageBuilder.Append(" Windows Service received an unsupported HL7 message from IP Address ");
fullErrorMessageBuilder.Append(ipAddress);
fullErrorMessageBuilder.Append(".\n\n");
fullErrorMessageBuilder.Append(errorMessage);
//
// Build email message without the full HL7 details
StringBuilder emailMessageBuilder = new StringBuilder(fullErrorMessageBuilder.ToString());
emailMessageBuilder.Append("\n\nThe Message ID is: ");
emailMessageBuilder.Append(HL7Utility.ParseGetRequiredMessageSegment(hl7Message, SegmentTypeNames.MSH));
emailMessageBuilder.Append("\n\nPlease check the server event log for the full HL7 message details.");
//
fullErrorMessageBuilder.Append("\n\nMessage Received:\n\n");
fullErrorMessageBuilder.Append(hl7Message);
//
// Record full error details including HL7 message contents in the event log
EventsLoggerSingleton.Instance.Log( fullErrorMessageBuilder.ToString(), eventLogEntryType );
//
if ( hl7Interface != null )
SendMailMessage( emailMessageBuilder.ToString(), hl7Interface );
/// <summary>
/// SendMailMessage
/// </summary>
private void SendMailMessage( string messageBody, HL7Interface hl7Interface )
try
HL7MailMessage mail = new HL7MailMessage();
//
mail.SendMessage( hl7Interface.InterfaceAdministratorEmail, "VBECS.HL7@med.DOMAIN.EXT", string.Concat("Error in VBECS HL7 Listener for ", hl7Interface.InterfaceName), messageBody, "smtp.DOMAIN.EXT" );
catch(Exception err)
string exceptionMessage = ExceptionManagement.DefaultPublisher.FormatExceptionInfoAndDumpToString(err);
//
EventsLoggerSingleton.Instance.Log( exceptionMessage, System.Diagnostics.EventLogEntryType.Error );
#endregion
#region Variables
// ************************************************************************************************************************************
// CR 2606
private static int _maxPatientFirstNameLength;
private static int _maxPatientLastNameLength;
private static int _maxPatientMiddleNameLength;
private static int _maxPatientFullNameLength;
private const string PATIENT_FIRST_NAME_MAXIMIUM_LENGTH = "PatientFirstNameMaximumLength";
private const string PATIENT_LAST_NAME_MAXIMIUM_LENGTH = "PatientLastNameMaximumLength";
private const string PATIENT_MIDDLE_NAME_MAXIMIUM_LENGTH = "PatientMiddleNameMaximumLength";
private const string PATIENT_FULL_NAME_MAXIMIUM_LENGTH = "PatientFullNameMaximumLength";
private const string PATIENT_NAME_FIELD_SIZE_NOT_SUPPORTED = "The Patient's Name field size exceeds VBECS maximum supported value.";
// ************************************************************************************************************************************
// CR 2659
private const string ACKNOWLEDGEMENT_ERROR_MESSAGE_KEY = "AcknowledgementErrorMessage";
private const string DETAILED_ERROR_MESSAGE_KEY = "DetailedErrorMessage";
private const string MERGE_MESSAGE_TYPE = "MPIF TRIGGER";
private const string MRG_SEGMENT_ID = "MRG";
private const string PID_SEGMENT_ID = "PID";
// ************************************************************************************************************************************
// CR 2665
private const string PATIENT_NAME_NOT_FOUND = "The Patient's Last Name or First Name was not found in the HL7 Message.";
// ************************************************************************************************************************************
// CR 2931
private const string INVALID_MERGE_FROM_PATIENT_NAME_INDICATOR = "MERGING INTO";
// ************************************************************************************************************************************
private const string CARRIAGE_RETURN = "\x0D";
private HL7Interface _interfaceControlParameters;
private Thread _listeningThread;
private TcpListener _listener;
#endregion
#region Delegates
/// <summary>
/// Delegate used for asynchronous call
/// </summary>
public delegate void ServeClientDelegate(Socket socket, HL7Interface intParms);
#endregion
#region Constructors
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>7/16/2010</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="9010"> 
///
<ExpectedInput>Valid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="9011"> 
///
<ExpectedInput>Invalid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// 
/// </summary>
static SimpleListener() 
try
// CR 2606
_maxPatientFirstNameLength = Convert.ToInt32( ConfigurationSettings.AppSettings[PATIENT_FIRST_NAME_MAXIMIUM_LENGTH] );
_maxPatientLastNameLength = Convert.ToInt32( ConfigurationSettings.AppSettings[PATIENT_LAST_NAME_MAXIMIUM_LENGTH] );
_maxPatientMiddleNameLength = Convert.ToInt32( ConfigurationSettings.AppSettings[PATIENT_MIDDLE_NAME_MAXIMIUM_LENGTH] );
_maxPatientFullNameLength = Convert.ToInt32( ConfigurationSettings.AppSettings[PATIENT_FULL_NAME_MAXIMIUM_LENGTH] );
catch(Exception ex)
EventsLoggerSingleton.Instance.Log( HL7Utility.GetInnerExceptionFromException(ex), System.Diagnostics.EventLogEntryType.Error );
//
throw;
/// <summary>
/// Constructor
/// </summary>
protected SimpleListener(HL7Interface intParms)
// CR 2510
// Set the unhandled exception handler
AppDomain currentDomain = AppDomain.CurrentDomain;
currentDomain.UnhandledException += new UnhandledExceptionEventHandler(currentDomain_UnhandledException);
if(( intParms.VbecsPortNumber < 1024 ) || ( intParms.VbecsPortNumber > 65535 ))
throw( new ArgumentOutOfRangeException( "VbecsPortNumber" ));
if(( intParms.VbecsIPAddress == null ))
throw( new ArgumentNullException("VbecsIPAddress") );
_interfaceControlParameters = intParms;
_listener = new TcpListener( intParms.VbecsIPAddress, intParms.VbecsPortNumber );
try
SetXmlConfigFileKeyValue("listenerIpAddress", intParms.VbecsIPAddress.ToString());
SetXmlConfigFileKeyValue("listenerPortNumber", intParms.VbecsPortNumber.ToString());
catch(Exception exc)
EventsLoggerSingleton.Instance.Log( exc.Message, System.Diagnostics.EventLogEntryType.Error );
/// <summary>
/// Constructor
/// </summary>
protected SimpleListener(IPAddress ipAddress, int port)
// CR 2510
// Set the unhandled exception handler
AppDomain currentDomain = AppDomain.CurrentDomain;
currentDomain.UnhandledException += new UnhandledExceptionEventHandler(currentDomain_UnhandledException);
if( ipAddress == null )
throw( new ArgumentNullException( "ipAddress" ) );
if(( port < 1024 ) || ( port > 65535 ))
throw( new ArgumentOutOfRangeException( "port" ) );
_interfaceControlParameters = null;
_listener = new TcpListener( ipAddress, port );
try
SetXmlConfigFileKeyValue("listenerIpAddress", ipAddress.ToString());
SetXmlConfigFileKeyValue("listenerPortNumber", port.ToString());
catch(Exception exc)
EventsLoggerSingleton.Instance.Log( exc.Message, System.Diagnostics.EventLogEntryType.Error );
#endregion
#region Properties
/// <summary>
/// Get/Set InterfaceControlParameters
/// </summary>
protected HL7Interface InterfaceControlParameters
get
return this._interfaceControlParameters;
set
this._interfaceControlParameters = value;
#endregion
#region Methods
/// <summary>
/// Start
/// </summary>
protected void Start()
lock( this )
System.Configuration.AppSettingsReader configurationAppSettings = new System.Configuration.AppSettingsReader();
_listeningThread = new Thread( new ThreadStart( BlockingStart ) );
_listeningThread.Start();
EventLog.WriteEntry( ((string)(configurationAppSettings.GetValue("serviceName", typeof(string)))) , "Listener has started on port: " + 
((string)(configurationAppSettings.GetValue("listenerPortNumber", typeof(string)))) + "  IP Address: " + ((string)(configurationAppSettings.GetValue("listenerIpAddress", typeof(string)))), EventLogEntryType.Information );
/// <summary>
/// Stop
/// </summary>
protected void Stop()
lock( this )
if( _listener != null )
_listener.Stop();
if( _listeningThread == null )
return;
_listeningThread.Abort();
_listeningThread.Join( 5000 );
/// <summary>
/// BlockingStart
/// </summary>
private void BlockingStart()
// CR 2510: add try/catch
try
lock( this )
_listener.Start();
ClientRequestContext cr = new ClientRequestContext();
ServeClientDelegate dlgt = new ServeClientDelegate(cr.ServeClient);
for(;;)
Socket _socket = _listener.AcceptSocket();
_socket.Blocking = true;
_socket.SetSocketOption(SocketOptionLevel.Socket, SocketOptionName.SendTimeout, 3000);
LingerOption lingerOption = new LingerOption(true, 2);
_socket.SetSocketOption(SocketOptionLevel.Socket, SocketOptionName.Linger, lingerOption);
if(_socket.Connected)
IAsyncResult ar = dlgt.BeginInvoke( _socket, _interfaceControlParameters, null, null);
dlgt.EndInvoke(ar);
_socket.Shutdown(SocketShutdown.Send);
// Moved the close method out of the above if statement to always close the socket.
_socket.Close();
catch(Exception ex)
// add log entry
System.Configuration.AppSettingsReader configurationAppSettings = new System.Configuration.AppSettingsReader();
string serviceName = (string) configurationAppSettings.GetValue("serviceName", typeof(string));
System.Diagnostics.EventLog.WriteEntry(serviceName, "BlockingStart method failed: " + ex.Message, EventLogEntryType.Error);
// rethrow exception
throw;
// CR 2510
// unhandled exception handler: logs error message, stops service
private void currentDomain_UnhandledException(object sender, UnhandledExceptionEventArgs e)
Exception unhandledException = e.ExceptionObject as Exception;
System.Configuration.AppSettingsReader configurationAppSettings = new System.Configuration.AppSettingsReader();
string serviceName = (string) configurationAppSettings.GetValue("serviceName", typeof(string));
System.Diagnostics.EventLog.WriteEntry(serviceName, "UnhandledExceptionHandler: " + unhandledException.Message, EventLogEntryType.Error);
System.ServiceProcess.ServiceController cntr = new System.ServiceProcess.ServiceController(serviceName, ".");
if(cntr.Status == System.ServiceProcess.ServiceControllerStatus.Running)
// Stop the service
try
cntr.Stop();
cntr.WaitForStatus(ServiceControllerStatus.Stopped, new TimeSpan(0,0,1,0,0));
catch(Exception ex)
System.Diagnostics.EventLog.WriteEntry(serviceName, "UnhandledExceptionHandler failed to stop service: " + ex.Message, EventLogEntryType.Error);
// CR2510 - end
/// <summary>
/// SetXmlConfigFileKeyValue
/// </summary>
private bool SetXmlConfigFileKeyValue(string keyName, string keyValue)
FileInfo _fileInfo = new FileInfo(Assembly.GetEntryAssembly().Location + ".config");
if(!_fileInfo.Exists)
throw new Exception("Missing config file");
XmlDocument xmlConfig = new XmlDocument();
xmlConfig.Load(_fileInfo.FullName);
bool keyExists = false;
foreach(XmlNode node in xmlConfig["configuration"]["appSettings"])
if(node.Name == "add")
if(node.Attributes.GetNamedItem("key").Value == keyName)
node.Attributes.GetNamedItem("value").Value = keyValue;
keyExists = true;
xmlConfig.Save(_fileInfo.FullName);
return keyExists;
/// <summary>
/// CR 2659: New method to verify VBECS required field data across all message types
/// 
/// Supported Validation
/// ---------------------------------------------------------------------------------------
/// (1) Patient name: the name fields found in the message must meet VBECS guidelines for 
///
maximum length and presence.  See the VBECS Application Interface Specification for 
///
details.
///
/// </summary>
private static Hashtable ValidateVbecsRequiredMessageContent( string hl7Message )
if ( hl7Message == null ) { throw( new ArgumentNullException( "hl7Message" ) ); }
//
Hashtable errorMessageTable = null;
// 
Hashtable segmentTable = ParseGetMessageSegments( hl7Message );
//
if ( segmentTable != null && segmentTable.Count > 0 )
char [] delimiters = hl7Message.ToCharArray( 3, 5 );
//
string pidSegment = segmentTable[PID_SEGMENT_ID] != null ? segmentTable[PID_SEGMENT_ID].ToString() : null;
//
if ( pidSegment != null )
string [] patientName = pidSegment.Split( delimiters[0] )[5].Split( delimiters[1] ) ;
//
if ( patientName != null && patientName.Length > 0 )
string patientLastName = patientName.Length >= 1 ? HL7Utility.ConvertString( patientName[0] ) : null;
string patientFirstName = patientName.Length >= 2 ? HL7Utility.ConvertString( patientName[1] ) : null;
string patientMiddleName = patientName.Length >= 3 ? HL7Utility.ConvertString( patientName[2] ) : null;
//
ValidatePatientName( patientLastName, patientFirstName, patientMiddleName, ref errorMessageTable );
else
// No PID segment found
ValidatePatientName( null, null, null, ref errorMessageTable );
//
if ( segmentTable.ContainsKey(MRG_SEGMENT_ID) )
string mrgSegment = segmentTable[MRG_SEGMENT_ID] != null ? segmentTable[MRG_SEGMENT_ID].ToString() : null;
//
if ( mrgSegment != null )
// CR 2931
string mergeFromPatientNameFullString = mrgSegment.Split( delimiters[0] )[7];
string [] mergeFromPatientNameComponents = mergeFromPatientNameFullString.Split( delimiters[1] );
//
// CR 2931: if merge-from name contains the invalid indicator, we ignore the length requirement; we won't be using this name anyway
if (mergeFromPatientNameFullString.IndexOf(INVALID_MERGE_FROM_PATIENT_NAME_INDICATOR) == -1 
&& mergeFromPatientNameComponents != null && mergeFromPatientNameComponents.Length > 0 )
string mergeFromPatientLastName = mergeFromPatientNameComponents.Length >= 1 ? HL7Utility.ConvertString( mergeFromPatientNameComponents[0] ) : null;
string mergeFromPatientFirstName = mergeFromPatientNameComponents.Length >= 2 ? HL7Utility.ConvertString( mergeFromPatientNameComponents[1] ) : null;
string mergeFromPatientMiddleName = mergeFromPatientNameComponents.Length >= 3 ? HL7Utility.ConvertString( mergeFromPatientNameComponents[2] ) : null;
//
ValidatePatientName( mergeFromPatientLastName, mergeFromPatientFirstName, mergeFromPatientMiddleName, ref errorMessageTable );
else
// Merge message but with no MRG segment found
ValidatePatientName( null, null, null, ref errorMessageTable );
//
// Clean up the table then return
if ( errorMessageTable != null )
ArrayList acknowledgementErrorList = new ArrayList();
StringBuilder acknowledgementErrorMessage = new StringBuilder();
//
foreach( string key in errorMessageTable.Keys )
if ( key != DETAILED_ERROR_MESSAGE_KEY )
object keyValue = errorMessageTable[key];
//
if ( !acknowledgementErrorList.Contains(keyValue) )
acknowledgementErrorList.Add( keyValue );
if ( acknowledgementErrorMessage.Length > 0 ) { acknowledgementErrorMessage.Append( " " ); }
acknowledgementErrorMessage.Append( keyValue );
//
string detailedErrorMessage = errorMessageTable.ContainsKey(DETAILED_ERROR_MESSAGE_KEY) ? errorMessageTable[DETAILED_ERROR_MESSAGE_KEY].ToString() : null; 
errorMessageTable = new Hashtable();
errorMessageTable.Add( ACKNOWLEDGEMENT_ERROR_MESSAGE_KEY, acknowledgementErrorMessage.ToString() );
errorMessageTable.Add( DETAILED_ERROR_MESSAGE_KEY, detailedErrorMessage );
//
return errorMessageTable;
/// <summary>
/// CR 2606: Verifies the PID segment required patient name fields are present 
/// and all fields included in the message fit within the max allowed by VBECS; 
/// returns error message(s) if any name field or the entire name length exceeds 
/// the max allowed value
/// 
/// CR 2659: Simplified to just validate a patient's name so that it might be
/// called multiple times (ex. merge for PID and MRG segments)
/// 
/// CR 2665: Changed last and first name existence check to an OR condition;
/// updated to use new error message
/// </summary>
private static void ValidatePatientName( string lastName, string firstName, string middleName, ref Hashtable errorMessageTable )
int fullNameFieldLength = 0;
//
StringBuilder detailedErrorMessage = null;
//
if ( errorMessageTable != null && errorMessageTable.ContainsKey("DetailedErrorMessage") )
detailedErrorMessage = new StringBuilder( errorMessageTable["DetailedErrorMessage"].ToString() );
// **********************************************************************************************
// Verify patient last name and first name are present in message
// CR 2665
if ( lastName == null || firstName == null )
if ( errorMessageTable == null ) { errorMessageTable = new Hashtable(); }
//
string key = "AcknowledgementErrorMessage.PATIENT_NAME_NOT_FOUND";
//
if ( !errorMessageTable.ContainsKey(key) )
errorMessageTable.Add( key, PATIENT_NAME_NOT_FOUND );
//
if ( detailedErrorMessage == null ) { detailedErrorMessage = new StringBuilder(PATIENT_NAME_NOT_FOUND); }
else { detailedErrorMessage.Append("\n").Append(PATIENT_NAME_NOT_FOUND); }
else
// **********************************************************************************************
// Verify patient's last name field size
//
int lastNameLength = lastName.Length;
//
fullNameFieldLength += lastNameLength;
//
if ( lastNameLength > _maxPatientLastNameLength )
if ( errorMessageTable == null ) { errorMessageTable = new Hashtable(); }
//
string key = "AcknowledgementErrorMessage.PATIENT_LAST_NAME_FIELD_SIZE_NOT_SUPPORTED";
//
if ( !errorMessageTable.ContainsKey(key) )
errorMessageTable.Add( key, PATIENT_NAME_FIELD_SIZE_NOT_SUPPORTED );
//
if ( detailedErrorMessage == null ) { detailedErrorMessage = new StringBuilder(); }
else { detailedErrorMessage.Append("\n"); }
//
detailedErrorMessage.Append( "The Patient's Last Name field size ("  );
detailedErrorMessage.Append( lastNameLength );
detailedErrorMessage.Append( ") exceeds VBECS maximum supported value (");
detailedErrorMessage.Append( _maxPatientLastNameLength );
detailedErrorMessage.Append( " characters)." );
// **********************************************************************************************
// Verify patient's first name field size
//
int firstNameLength = firstName.Length;
//
// The extra 1 here accounts for the comma in VistA
fullNameFieldLength += (firstNameLength + 1);
//
if ( firstNameLength > _maxPatientLastNameLength )
if ( errorMessageTable == null ) { errorMessageTable = new Hashtable(); }
//
string key = "AcknowledgementErrorMessage.PATIENT_FIRST_NAME_FIELD_SIZE_NOT_SUPPORTED";
//
if ( !errorMessageTable.ContainsKey(key) )
errorMessageTable.Add( key, PATIENT_NAME_FIELD_SIZE_NOT_SUPPORTED );
//
if ( detailedErrorMessage == null ) { detailedErrorMessage = new StringBuilder(); }
else { detailedErrorMessage.Append("\n"); }
//
detailedErrorMessage.Append( "The Patient's First Name field size ("  );
detailedErrorMessage.Append( firstNameLength );
detailedErrorMessage.Append( ") exceeds VBECS maximum supported value (");
detailedErrorMessage.Append( _maxPatientLastNameLength );
detailedErrorMessage.Append( " characters)." );
// **********************************************************************************************
// Verify patient's middle name field size
//
if ( middleName != null )
int middleNameLength = middleName.Length;
//
// The extra 1 here accounts for the space in VistA
fullNameFieldLength += (middleNameLength + 1);
//
if ( middleNameLength > _maxPatientLastNameLength )
if ( errorMessageTable == null ) { errorMessageTable = new Hashtable(); }
//
string key = "AcknowledgementErrorMessage.PATIENT_MIDDLE_NAME_FIELD_SIZE_NOT_SUPPORTED";
//
if ( !errorMessageTable.ContainsKey(key) )
errorMessageTable.Add( key, PATIENT_NAME_FIELD_SIZE_NOT_SUPPORTED );
//
if ( detailedErrorMessage == null ) { detailedErrorMessage = new StringBuilder(); }
else { detailedErrorMessage.Append("\n"); }
//
detailedErrorMessage.Append( "The Patient's Middle Name field size ("  );
detailedErrorMessage.Append( middleNameLength );
detailedErrorMessage.Append( ") exceeds VBECS maximum supported value (");
detailedErrorMessage.Append( _maxPatientLastNameLength );
detailedErrorMessage.Append( " characters)." );
// **********************************************************************************************
// Verify total name length
//
if ( fullNameFieldLength > _maxPatientFullNameLength )
if ( errorMessageTable == null ) { errorMessageTable = new Hashtable(); }
//
string key = "AcknowledgementErrorMessage.PATIENT_FULL_NAME_FIELD_SIZE_NOT_SUPPORTED";
//
if ( !errorMessageTable.ContainsKey(key) )
errorMessageTable.Add( key, PATIENT_NAME_FIELD_SIZE_NOT_SUPPORTED );
//
if ( detailedErrorMessage == null ) { detailedErrorMessage = new StringBuilder(); }
else { detailedErrorMessage.Append("\n"); }
//
detailedErrorMessage.Append( "The Patient's Full Name field size (" );
detailedErrorMessage.Append( fullNameFieldLength );
detailedErrorMessage.Append( ") exceeds VBECS maximum supported value (");
detailedErrorMessage.Append( _maxPatientFullNameLength );
detailedErrorMessage.Append( " characters)." );
//
if ( detailedErrorMessage != null && errorMessageTable != null )
if ( errorMessageTable.ContainsKey("DetailedErrorMessage") )
errorMessageTable["DetailedErrorMessage"] = detailedErrorMessage;
else
errorMessageTable.Add( "DetailedErrorMessage", detailedErrorMessage );
/// <summary>
/// CR 2659: returns desired HL7 message segments (ex. used to get the PID and MRG from 
/// patient merge messages)
/// </summary>
private static Hashtable ParseGetMessageSegments( string hl7Message )
if ( hl7Message == null )
throw( new ArgumentNullException( "hl7Message" ) );
//
string [] segments = hl7Message.Split( new char[]{'\r'} );
//
int returnCount = segments[0].IndexOf(MERGE_MESSAGE_TYPE) > -1 ? 2: 1;
int updatedCount = 0;
//
Hashtable segmentTable = new Hashtable( returnCount );
segmentTable.Add( PID_SEGMENT_ID, null );
if ( returnCount == 2 ) { segmentTable.Add( MRG_SEGMENT_ID, null ); }
//
for( int i = 0; i <= segments.Length -1; i++ )
if ( segments[i] != null && segments[i].Length > 3 )
string segmentId = segments[i].Substring(0, 3);
//
// If this is a merge message we need to check the PID and MRG segments
if ( segmentId == PID_SEGMENT_ID || (returnCount == 2 && segmentId == MRG_SEGMENT_ID) )
segmentTable[segmentId] = segments[i];
updatedCount += 1;
//
if ( updatedCount == returnCount ) { break; }
//
return segmentTable;
#endregion
