#region References
using System;
using System.IO;
using System.Text;
using System.Data;
using System.Collections;
#endregion
namespace EXT.DOMAIN.vbecs.DAL.HL7.OpenLibrary.Messages
#region Header
//<Package>Package: VBECS - VistA Blood Establishment Computer System</Package>
//<Warning> WARNING: Per VHA Directive $VADIRECTIVE this class should not be modified</Warning>
//<MedicalDevice> Medical Device #: $MEDDEVICENO</MedicalDevice>
//<Developers>
//
<Developer></Developer>
//</Developers>
//<SiteName>Hines OIFO</SiteName>
//<CreationDate>5/23/2008</CreationDate>
//<Note>The Food and Drug Administration classifies this software as a medical device.  As such, it may not be changed in any way. Modifications to this software may result in an adulterated medical device under 21CFR820, the use of which is considered to be a violation of US Federal Statutes.  Acquiring and implementing this software through the Freedom of information Act requires the implementor to assume total responsibility for the software, and become a registered manufacturer of a medical device, subject to FDA regulations</Note>
//<summary>The HL7BtsMessage type represents the response to HL7 v2.5 Blood Product Transfusion/Disposition message. It implements the HL7ProtocolMessage type and is not meant to be inherited.</summary>
#endregion 
/// <summary>
/// New class for BCE (CR 2962)
/// </summary>
public sealed class HL7BrtMessage : HL7ProtocolMessage
#region Variables
/// <summary>
/// Response message(BRT) to a Patient Transfusion\Disposition Message(BTS)
/// </summary>
private const string MESSAGE_TYPE = "BRT~O32";
private const bool RESPONSE_REQUIRED_INDICATOR = false;
private string _errorCode;
private string _errorText;
private string _ackCode;
private string _err;
private string _msh;
private string _msa;
#endregion
#region Constructors
/// <summary>
/// Empty static constructor added to get rid of "beforefieldinit" attribute generated by compiler.
/// </summary>
static HL7BrtMessage() {}
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>5/23/2008</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="8612"> 
///
<ExpectedInput>string</ExpectedInput>
///
<ExpectedOutput>HL7BrtMessage</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="8613"> 
///
<ExpectedInput>null</ExpectedInput>
///
<ExpectedOutput>ArgumentNullException</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Constructor to load HL7 Message.
/// </summary>
/// <param name="message"></param>
public HL7BrtMessage( string message )
: base( message )
if( message == null )
throw( new ArgumentNullException( "message" ) );
//
_message = message;
//
_messageControlID = HL7Utility.GetMessageControlID( message );
//
LoadDataFromHL7Message();
#endregion
#region Public Methods
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>5/23/2008</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="8614"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>string</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="8615"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Overridden method to get the full hl7 message.
/// </summary>
/// <returns></returns>
public override string GetMessage()
return Message;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>5/23/2008</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="8618"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>string</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="8619"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Overridden method to get the Message Control ID
/// </summary>
/// <returns></returns>
public override string GetMessageControlID()
return MessageControlID;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>5/23/2008</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="8620"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>string</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="8621"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Overriden method to get the Message Type.
/// </summary>
/// <returns></returns>
public override string GetMessageType()
return MessageType;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>5/23/2008</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="8616"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>bool</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="8617"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// IsResponseRequired
/// </summary>
public override bool IsResponseRequired()
return RESPONSE_REQUIRED_INDICATOR;
#endregion
#region Protected Methods
/// <summary>
/// WriteHL7MessageBody
/// </summary>
/// <param name="writer"></param>
protected override void WriteHL7MessageBody( StreamWriter writer )
if( writer == null )
throw( new ArgumentNullException( "writer" ) );
writer.Write( this.Message );
#endregion
#region Private Methods
/// <summary>
/// LoadDataFromHL7Message
/// </summary>
private void LoadDataFromHL7Message()
_msh = HL7Utility.ParseGetRequiredMessageSegment(this.Message, SegmentTypeNames.MSH);
_msa = HL7Utility.ParseGetRequiredMessageSegment(this.Message, SegmentTypeNames.MSA);
_err = HL7Utility.ParseGetOptionalMessageSegment(this.Message, SegmentTypeNames.ERR);
_ackCode = HL7Utility.ParseGetAckCode( this.Message );
#endregion
#region Properties
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>5/23/2008</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="8628"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>string</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="8629"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// AcknowledgementCode
/// </summary>
public string AcknowledgementCode
get
return _ackCode;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>5/23/2008</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="8742"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>string</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="8743"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// ErrorCode
/// </summary>
public string ErrorCode
get
if ( _errorCode == null )
string [] errorCodeAndMessage = HL7.OpenLibrary.HL7Utility.ParseGetErrorCodeAndMessage( _message );
//
if ( errorCodeAndMessage != null )
_errorCode = errorCodeAndMessage[0];
//
if ( errorCodeAndMessage.Length > 1 )
_errorText = errorCodeAndMessage[1];
//
return _errorCode;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>5/23/2008</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="8630"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>string</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="8631"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// ErrorText
/// </summary>
public string ErrorText
get
if ( _errorText == null )
string [] errorCodeAndMessage = HL7.OpenLibrary.HL7Utility.ParseGetErrorCodeAndMessage( _message );
//
if ( errorCodeAndMessage != null )
_errorCode = errorCodeAndMessage[0];
//
if ( errorCodeAndMessage.Length > 1 )
_errorText = errorCodeAndMessage[1];
//
return _errorText;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>5/23/2008</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="8634"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>string</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="8635"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Message
/// </summary>
public string Message
get
return _message;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>5/23/2008</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="8632"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>string</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="8633"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// MessageControlID
/// </summary>
public string MessageControlID
get
return _messageControlID;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>5/23/2008</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="8636"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>string</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="8637"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// MessageType
/// </summary>
public string MessageType
get
return MESSAGE_TYPE;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>5/23/2008</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="8624"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>string</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="8625"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// MSH
/// </summary>
public string MSH
get
return _msh;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>5/23/2008</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="8622"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>string</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="8623"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// MSA
/// </summary>
public string MSA
get
return _msa;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>5/23/2008</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="8626"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>string</ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="8627"> 
///
<ExpectedInput>NA</ExpectedInput>
///
<ExpectedOutput>NA</ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// ERR
/// </summary>
public string ERR
get
return _err;
#endregion
