using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Windows.Forms;
using EXT.DOMAIN.vbecs.reports.OrderHistory;
namespace EXT.DOMAIN.vbecs.GUI
/// <summary>
/// Class FrmOrderHistoryReport
/// </summary>
public class FrmOrderHistoryReport : EXT.DOMAIN.vbecs.GUI.VbecsBaseForm
private BOL.OrderReport _orderReport;
// report for multiple order report
private CrystalDecisions.CrystalReports.Engine.ReportClass  _multiOrderReport;
// report for single order report
private SingleOrderHistory _singleOrderHistoryReport = new SingleOrderHistory();
private System.Windows.Forms.Button btnClose;
private System.Windows.Forms.Button btnPrint;
private System.Windows.Forms.GroupBox grpImage;
private System.Windows.Forms.PictureBox picImage;
private System.Windows.Forms.Panel pnlReport;
private CrystalDecisions.Windows.Forms.CrystalReportViewer crvOrderHistory;
private System.Windows.Forms.PrintDialog printDialog1;
private System.ComponentModel.IContainer components = null;
#region constructors
/// <summary>
/// BR_86.04, BR_86.06 (BRs that define how the report is formatted)
/// </summary>
/// <param name="orderReport"></param>
public FrmOrderHistoryReport(BOL.OrderReport orderReport)
InitializeComponent();
SetComponentProperties();
_orderReport = orderReport;
using (new WaitCursor())
DataSet dsReportData = _orderReport.CreateReport();
if (_orderReport.IsSingleOrderReport)
DisplaySingleOrderReport(dsReportData);
else
DisplayMultiOrderReport(dsReportData);
#endregion
#region methods
/// <summary>
/// The dataset contains 3 tables:
/// Table 1 contains the high level information related to the order
/// Table 2 contains historical specimen information (SpecimenHistory table)
/// Table 3 contains reflex tests associated with the order
/// </summary>
/// <param name="reportData"></param>
private void DisplaySingleOrderReport(DataSet reportData)
this.SetThisHelpFile(this, Common.StrRes.HelpFiles.UC086.FrmOrderHistoryReport_Single());
//
if (reportData == null || reportData.Tables.Count == 0)
throw new ArgumentException(Common.StrRes.SysErrMsg.Common.InvalidFormat("Report DataSet").ResString);
// DataSet to pass to the Report Header subreport
DataSet dsHeader = BOL.VbecsReport.GetReportHeader(ThisUser.UserName);
#if DEBUG
reportData.WriteXml("c:\\dataset.xml", XmlWriteMode.WriteSchema);
#endif
try
// Set data source
_singleOrderHistoryReport.SetDataSource(reportData);
int index = ( reportData.Tables.IndexOf("SpecimenHistory"));
if ( reportData.Tables.IndexOf("SpecimenHistory") != -1)
_singleOrderHistoryReport.OpenSubreport("SpecimenHistory.rpt").SetDataSource(reportData.Tables[reportData.Tables.IndexOf("SpecimenHistory")]);
if ( reportData.Tables.IndexOf("ReflexTests") != -1)
_singleOrderHistoryReport.OpenSubreport("ReflexTests.rpt").SetDataSource(reportData.Tables[reportData.Tables.IndexOf("ReflexTests")]);
// Add report to report viewer
this.crvOrderHistory.ReportSource = _singleOrderHistoryReport;
controls.VbecsFunction.RenameCrystalReportTab(this.crvOrderHistory, "Single Order History Report");
// Populate parameters of report
_singleOrderHistoryReport.SetParameterValue("ReportTitle", "Single Order History Report");
// Set the subreport data source
this._singleOrderHistoryReport.OpenSubreport("ReportHeaderPortrait.rpt").SetDataSource(dsHeader);
catch(CrystalDecisions.CrystalReports.Engine.OutOfLicenseException)
GuiMessenger.ShowMessageBox(Common.StrRes.SysErrMsg.Common.ReportsOutOfLicense());
return;
/// <summary>
/// DisplayMultiOrderReport
/// </summary>
/// <param name="reportData"></param>
private void DisplayMultiOrderReport(DataSet reportData)
this.SetThisHelpFile(this, Common.StrRes.HelpFiles.UC086.FrmOrderHistoryReport());
//
if (reportData == null || reportData.Tables.Count == 0)
throw new ArgumentException(Common.StrRes.SysErrMsg.Common.InvalidFormat("Report DataSet").ResString);
if (_orderReport.SortByTreatingSpecialty)
_multiOrderReport = new MultiOrderTransfusionSpecialty();
else
_multiOrderReport = new MultiOrderOrderingLocation();
#if DEBUG
//reportData.WriteXml("c:\\_multiOrder.xml", XmlWriteMode.WriteSchema);
#endif
// Set data source
_multiOrderReport.SetDataSource(reportData);
// Add report to report viewer
this.crvOrderHistory.ReportSource = _multiOrderReport;
controls.VbecsFunction.RenameCrystalReportTab(this.crvOrderHistory, "Order History Report");
// Populate parameters of report
_multiOrderReport.SetParameterValue("ReportTitle", "Order History Report");
// Set the subreport data sources
DataSet dsHeader = BOL.VbecsReport.GetReportHeader(ThisUser.UserName);
_multiOrderReport.OpenSubreport("ReportHeaderPortrait.rpt").SetDataSource(dsHeader);
//string reportCriteria = "Order received between " + _orderReport.StartDate.ToString("mmddyyyy") + " and " + _orderReport.EndDate.ToString("mmddyyyy") + 
//
", sorted by " + (_orderReport.SortByTreatingSpecialty ? "treating specialty." : "ordering location.") ;
DataSet dsFooter = BOL.VbecsReport.GetReportFooter(_orderReport.SearchCriteria);
_multiOrderReport.OpenSubreport("ReportFooterPortrait.rpt").SetDataSource(dsFooter);
/// <summary>
/// Clean up any resources being used.
/// </summary>
protected override void Dispose( bool disposing )
if( disposing )
if (components != null) 
components.Dispose();
base.Dispose( disposing );
#region Designer generated code
/// <summary>
/// Required method for Designer support - do not modify
/// the contents of this method with the code editor.
/// </summary>
private void InitializeComponent()
System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(FrmOrderHistoryReport));
this.btnClose = new System.Windows.Forms.Button();
this.btnPrint = new System.Windows.Forms.Button();
this.grpImage = new System.Windows.Forms.GroupBox();
this.picImage = new System.Windows.Forms.PictureBox();
this.crvOrderHistory = new CrystalDecisions.Windows.Forms.CrystalReportViewer();
this.pnlReport = new System.Windows.Forms.Panel();
this.printDialog1 = new System.Windows.Forms.PrintDialog();
this.grpImage.SuspendLayout();
this.pnlReport.SuspendLayout();
this.SuspendLayout();
// 
// vbecsLogo1
// 
this.vbecsLogo1.Name = "vbecsLogo1";
this.vbecsLogo1.TabIndex = 1;
this.vbecsLogo1.Title = "Order History Report";
// 
// lblRequiredField
// 
this.lblRequiredField.Name = "lblRequiredField";
this.lblRequiredField.TabIndex = 0;
// 
// btnClose
// 
this.btnClose.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
this.btnClose.DialogResult = System.Windows.Forms.DialogResult.Cancel;
this.btnClose.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
this.btnClose.Location = new System.Drawing.Point(564, 416);
this.btnClose.Name = "btnClose";
this.btnClose.TabIndex = 2;
this.btnClose.Text = "&Close";
this.btnClose.Click += new System.EventHandler(this.btnClose_Click);
// 
// btnPrint
// 
this.btnPrint.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
this.btnPrint.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
this.btnPrint.Image = ((System.Drawing.Image)(resources.GetObject("btnPrint.Image")));
this.btnPrint.ImageAlign = System.Drawing.ContentAlignment.MiddleLeft;
this.btnPrint.Location = new System.Drawing.Point(484, 416);
this.btnPrint.Name = "btnPrint";
this.btnPrint.TabIndex = 1;
this.btnPrint.Text = "&Print";
this.btnPrint.Click += new System.EventHandler(this.btnPrint_Click);
// 
// grpImage
// 
this.grpImage.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
| System.Windows.Forms.AnchorStyles.Left)));
this.grpImage.Controls.Add(this.picImage);
this.grpImage.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
this.grpImage.Location = new System.Drawing.Point(4, 0);
this.grpImage.Name = "grpImage";
this.grpImage.Size = new System.Drawing.Size(52, 412);
this.grpImage.TabIndex = 3;
this.grpImage.TabStop = false;
// 
// picImage
// 
this.picImage.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
this.picImage.Image = ((System.Drawing.Image)(resources.GetObject("picImage.Image")));
this.picImage.Location = new System.Drawing.Point(4, 12);
this.picImage.Name = "picImage";
this.picImage.Size = new System.Drawing.Size(45, 45);
this.picImage.SizeMode = System.Windows.Forms.PictureBoxSizeMode.AutoSize;
this.picImage.TabIndex = 0;
this.picImage.TabStop = false;
// 
// crvOrderHistory
// 
this.crvOrderHistory.ActiveViewIndex = -1;
this.crvOrderHistory.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
| System.Windows.Forms.AnchorStyles.Left) 
| System.Windows.Forms.AnchorStyles.Right)));
this.crvOrderHistory.DisplayGroupTree = false;
this.crvOrderHistory.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
this.crvOrderHistory.Location = new System.Drawing.Point(60, 4);
this.crvOrderHistory.Name = "crvOrderHistory";
this.crvOrderHistory.ReportSource = null;
this.crvOrderHistory.ShowCloseButton = false;
this.crvOrderHistory.ShowExportButton = false;
this.crvOrderHistory.ShowPrintButton = false;
this.crvOrderHistory.ShowRefreshButton = false;
this.crvOrderHistory.Size = new System.Drawing.Size(576, 408);
this.crvOrderHistory.TabIndex = 0;
// 
// pnlReport
// 
this.pnlReport.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
| System.Windows.Forms.AnchorStyles.Left) 
| System.Windows.Forms.AnchorStyles.Right)));
this.pnlReport.Controls.Add(this.crvOrderHistory);
this.pnlReport.Controls.Add(this.btnPrint);
this.pnlReport.Controls.Add(this.btnClose);
this.pnlReport.Controls.Add(this.grpImage);
this.pnlReport.Location = new System.Drawing.Point(0, 32);
this.pnlReport.Name = "pnlReport";
this.pnlReport.Size = new System.Drawing.Size(640, 440);
this.pnlReport.TabIndex = 2;
// 
// printDialog1
// 
this.printDialog1.AllowPrintToFile = false;
// 
// FrmOrderHistoryReport
// 
this.AcceptButton = this.btnPrint;
this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
this.CancelButton = this.btnClose;
this.ClientSize = new System.Drawing.Size(642, 473);
this.Controls.Add(this.pnlReport);
this.hlphelpChm.SetHelpKeyword(this, "Order_History_Report.htm");
this.hlphelpChm.SetHelpNavigator(this, System.Windows.Forms.HelpNavigator.Topic);
this.MinimumSize = new System.Drawing.Size(600, 450);
this.Name = "FrmOrderHistoryReport";
this.RequiredFieldsLabel = true;
this.hlphelpChm.SetShowHelp(this, true);
this.Text = "VBECS - Order History Report";
this.Controls.SetChildIndex(this.pnlReport, 0);
this.Controls.SetChildIndex(this.vbecsLogo1, 0);
this.Controls.SetChildIndex(this.lblRequiredField, 0);
this.grpImage.ResumeLayout(false);
this.pnlReport.ResumeLayout(false);
this.ResumeLayout(false);
#endregion
private void SetComponentProperties()
this.vbecsLogo1.Title = this.Text.Replace("VBECS - ","");
// CR 2693
// hlpHelp
// 
this.hlpHelp.HelpNamespace = Environment.CurrentDirectory+"\\VBECS.chm";
// 
// hlphelpChm
// 
this.hlphelpChm.HelpNamespace = Environment.CurrentDirectory+"\\VBECS.chm";
#endregion
#region events
private void btnPrint_Click(object sender, System.EventArgs e)
System.Drawing.Printing.PrinterSettings settings = new System.Drawing.Printing.PrinterSettings();
printDialog1.PrinterSettings = settings;
if (printDialog1.ShowDialog(this) == DialogResult.OK)
if (_orderReport.IsSingleOrderReport)
_singleOrderHistoryReport.PrintOptions.PrinterName = settings.PrinterName;
_singleOrderHistoryReport.PrintToPrinter(settings.Copies,settings.Collate,settings.FromPage,settings.ToPage);
else
_multiOrderReport.PrintOptions.PrinterName = settings.PrinterName;
_multiOrderReport.PrintToPrinter(settings.Copies,settings.Collate,settings.FromPage,settings.ToPage);
private void btnClose_Click(object sender, System.EventArgs e)
this.Close();
#endregion
