using System;
using EXT.DOMAIN.vbecs.GUI.controls;
namespace EXT.DOMAIN.vbecs.GUI
#region Header
///<Package>Package: VBECS - VistA Blood Establishment Computer System</Package>
///<Warning> WARNING: Per VHA Directive $VADIRECTIVE this class should not be modified</Warning>
///<MedicalDevice> Medical Device #: $MEDDEVICENO</MedicalDevice>
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>3/18/2005</CreationDate>
///<Note>The Food and Drug Administration classifies this software as a medical device.  As such, it may not be changed in any way. Modifications to this software may result in an adulterated medical device under 21CFR820, the use of which is considered to be a violation of US Federal Statutes.  Acquiring and implementing this software through the Freedom of information Act requires the implementor to assume total responsibility for the software, and become a registered manufacturer of a medical device, subject to FDA regulations</Note>
/// <summary>
/// VBECS application startup lock class. Ensures that only one instace of 
/// the VBECS can run in the user session and that VBECS is not run when 
/// there is the VBECS Administrator running on the server in single user mode.
/// </summary>
#endregion
public class VbecsAppStartupLock : VbecsAppSyncLockBase
/// <summary>
/// Local VBECS application synchronization token (mutex name).
/// Used to indicate that VBECS application is running in the user session.
/// </summary>
private const string LocalVbecsSyncToken = "EXT.DOMAIN.vbecs.LocalVbecsInSessionSyncLockToken";
private SharedWin32Mutex _vbecsLocalMutex;
private SharedWin32Mutex _vbecsGlobalMutex;
private SharedWin32Mutex _adminSingleUserModeGlobalMutex;
private bool _onlyOneInstanceOfVbecsIsRunningInSession;
private bool _adminIsNotRunningInSingleUserMode;
/// <summary>
/// Creates new locks and checks if there're an existing locks.
/// </summary>
public VbecsAppStartupLock() : base() {}
/// <summary>
/// Obtains new locks and checks for existing locks. 
/// </summary>
protected override void ObtainAppSpecificLocks()
_vbecsLocalMutex = new SharedWin32Mutex( LocalVbecsSyncToken, out _onlyOneInstanceOfVbecsIsRunningInSession );
if (Common.VbecsConfig.Current.EnvironmentType.ToUpper() == "M")
_adminSingleUserModeGlobalMutex = new SharedWin32Mutex( GlobalAdminTestSingleUserModeSyncToken, out _adminIsNotRunningInSingleUserMode );
_vbecsGlobalMutex = new SharedWin32Mutex( GlobalTestVbecsSyncToken );
else
_adminSingleUserModeGlobalMutex = new SharedWin32Mutex( GlobalAdminProdSingleUserModeSyncToken, out _adminIsNotRunningInSingleUserMode );
_vbecsGlobalMutex = new SharedWin32Mutex( GlobalProdVbecsSyncToken );
CloseAndNullifyMutex( ref _adminSingleUserModeGlobalMutex );
/// <summary>
/// Releases locks.
/// </summary>
protected override void ReleaseAppSpecificLocks()
CloseAndNullifyMutex( ref _vbecsLocalMutex );
CloseAndNullifyMutex( ref _vbecsGlobalMutex );
CloseAndNullifyMutex( ref _adminSingleUserModeGlobalMutex );
/// <summary>
/// Sets member lock variables to null.
/// </summary>
protected override void NullifyAppSpecificLocks()
_vbecsLocalMutex = _vbecsGlobalMutex = _adminSingleUserModeGlobalMutex;
/// <summary>
/// Indicates if there's another instance of VBECS running in the user session.
/// </summary>
public bool IsAnotherInstanceOfVbecsIsRunningInSession
get
return !_onlyOneInstanceOfVbecsIsRunningInSession;
/// <summary>
/// Indicates if there's an instance of VBECS Administrator running in 
/// single user mode on the server. 
/// </summary>
public bool IsAdminRunningOnServerInSingleUserMode
get
return !_adminIsNotRunningInSingleUserMode;
