using System;
using System.Collections;
using System.ComponentModel;
using System.Configuration.Install;
using System.Collections.Specialized;
using System.ServiceProcess;
using System.IO;
using System.Reflection;
using System.Xml;
using Microsoft.Win32;
namespace EXT.DOMAIN.vbecs.DAL.HL7.Listener.WinService
/// <summary>
/// This is a custom project installer.
/// Applies a unique name to the service using the /name switch
/// Sets user name and password using the /user and /password switches
/// Allows the use of a local account using the /account switch
/// </summary>
[RunInstaller(true)]
public class ScriptedInstaller : Installer
private ServiceInstaller serviceInstaller;
private ServiceProcessInstaller processInstaller;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>7/22/2010</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="9058"> 
///
<ExpectedInput>Valid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="9059"> 
///
<ExpectedInput>Invalid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Constructor
/// </summary>
public ScriptedInstaller()
processInstaller
= new ServiceProcessInstaller();
serviceInstaller
= new ServiceInstaller();
// Set some defaults
processInstaller.Account
= System.ServiceProcess.ServiceAccount.LocalSystem;
serviceInstaller.StartType
= ServiceStartMode.Automatic;
serviceInstaller.ServiceName
= "VBECS HL7 Multi Listener Service";
Installers.Add(serviceInstaller);
Installers.Add(processInstaller);
#region Access parameters
/// <summary>
/// Return the value of the parameter in dicated by key
/// </summary>
/// <param name="key">Context parameter key</param>
/// <returns>Context parameter specified by key</returns>
public string GetContextParameter(string key) 
string sValue = "";
try 
sValue = this.Context.Parameters[key].ToString();
catch 
sValue = "";
return sValue;
#endregion
/// <summary>
/// This method is run before the install process.
/// This method is overriden to set the following parameters:
/// service name (/name switch)
/// account type (/account switch)
/// for a user account user name (/user switch)
/// for a user account password (/password switch)
/// Note that when using a user account, if the user name or password is not set,
/// the installing user is prompted for the credentials to use.
/// </summary>
/// <param name="savedState"></param>
protected override void OnBeforeInstall(IDictionary savedState)
base.OnBeforeInstall(savedState);
bool isUserAccount = false;
// Decode the command line switches
string serviceName = GetContextParameter("serviceName");
if( serviceName == "" )
serviceName = "VBECS HL7 Multi Listener " + GetContextParameter("server") + "_" + GetContextParameter("database");
serviceInstaller.ServiceName = serviceName;
SetXmlConfigFileKeyValue("serviceName",this.serviceInstaller.ServiceName);
SetXmlConfigFileKeyValue("PrimaryDbConnectionString","Connection Timeout=90"
+ ";Data Source=" + GetContextParameter("server") + ";Initial Catalog=" + GetContextParameter("database")
+ ";persist security info=False;packet size=8192;integrated security=SSPI"
+ ";Application Name=VBECS");
SetXmlConfigFileKeyValue("listenerIpAddress", GetContextParameter("listenerIpAddress"));
SetXmlConfigFileKeyValue("listenerPortNumber", GetContextParameter("listenerPortNumber"));
// What type of credentials to use to run the service
// The default is User
string acct
= GetContextParameter("account");
if (0 == acct.Length) acct = "user";
// Decode the type of account to use
switch (acct) 
case "user":
processInstaller.Account = System.ServiceProcess.ServiceAccount.User;
isUserAccount = true;
break;
case "localservice":
processInstaller.Account = System.ServiceProcess.ServiceAccount.LocalService;
break;
case "localsystem":
processInstaller.Account = System.ServiceProcess.ServiceAccount.LocalSystem;
break;
case "networkservice":
processInstaller.Account = System.ServiceProcess.ServiceAccount.NetworkService;
break;
default:
processInstaller.Account = System.ServiceProcess.ServiceAccount.User;
isUserAccount = true;
break;
// Should I use a user account?
if (isUserAccount) 
// If we need to use a user account, set the user name and password
processInstaller.Username = GetContextParameter("username");
processInstaller.Password = GetContextParameter("password");
/// <summary>
/// Modify the registry to install the new service
/// </summary>
/// <param name="stateServer"></param>
public override void Install(IDictionary stateServer)
RegistryKey system,
//HKEY_LOCAL_MACHINE\Services\CurrentControlSet
currentControlSet,
//...\Services
services,
//...\<Service Name>
service,
//...\Parameters - this is where you can put service-specific configuration
config; 
base.Install(stateServer);
// Define the registry keys
// Navigate to services
system
= Registry.LocalMachine.OpenSubKey("System");
currentControlSet
= system.OpenSubKey("CurrentControlSet");
services
= currentControlSet.OpenSubKey("Services");
// Add the service
service
= services.OpenSubKey(this.serviceInstaller.ServiceName, true);
// Default service description
service.SetValue("Description", "Receives incoming HL7 messages for VBECS.");
// Display the assembly image path and modify to add the service name
// The executable then strips the name out of the image
Console.WriteLine("ImagePath: " + service.GetValue("ImagePath"));
string imagePath = (string)service.GetValue("ImagePath");
imagePath
+= " -s" + this.serviceInstaller.ServiceName;
service.SetValue("ImagePath", imagePath);
// Create a parameters subkey
config
= service.CreateSubKey("Parameters");
// Close keys
config.Close();
service.Close();
services.Close();
currentControlSet.Close();
system.Close();
/// <summary>
/// Uninstall based on the service name
/// </summary>
/// <param name="savedState"></param>
protected override void OnBeforeUninstall(IDictionary savedState)
base.OnBeforeUninstall(savedState);
// Set the service name based on the config file.
serviceInstaller.ServiceName = GetXmlConfigFileKeyValue("serviceName");
/// <summary>
/// Modify the registry to remove the service
/// </summary>
/// <param name="stateServer"></param>
public override void Uninstall(IDictionary stateServer)
RegistryKey system,
//HKEY_LOCAL_MACHINE\Services\CurrentControlSet
currentControlSet,
//...\Services
services,
//...\<Service Name>
service;
//...\Parameters - this is where you can put service-specific configuration
base.Uninstall(stateServer);
// Navigate down the registry path
system
= Registry.LocalMachine.OpenSubKey("System");
currentControlSet
= system.OpenSubKey("CurrentControlSet");
services
= currentControlSet.OpenSubKey("Services");
service
= services.OpenSubKey(GetXmlConfigFileKeyValue("serviceName"),true);
// Remove the parameters key
service.DeleteSubKeyTree("Parameters");
// Close keys
service.Close();
services.Close();
currentControlSet.Close();
system.Close();
private static bool SetXmlConfigFileKeyValue(string keyName, string keyValue)
FileInfo _fileInfo = new FileInfo(Assembly.GetExecutingAssembly().Location + ".config");
if(!_fileInfo.Exists)
throw new InstallException("Missing config file");
XmlDocument xmlConfig = new XmlDocument();
xmlConfig.Load(_fileInfo.FullName);
bool keyExists = false;
foreach(XmlNode node in xmlConfig["configuration"]["appSettings"])
if(node.Name == "add")
if(node.Attributes.GetNamedItem("key").Value == keyName)
node.Attributes.GetNamedItem("value").Value = keyValue;
keyExists = true;
xmlConfig.Save(_fileInfo.FullName);
return keyExists;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>7/22/2010</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="9056"> 
///
<ExpectedInput>Valid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="9057"> 
///
<ExpectedInput>Invalid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// GetXmlConfigFileKeyValue
/// </summary>
/// <param name="keyName"></param>
/// <returns></returns>
public static string GetXmlConfigFileKeyValue(string keyName)
FileInfo _fileInfo = new FileInfo(Assembly.GetExecutingAssembly().Location + ".config");
if(!_fileInfo.Exists)
throw new InstallException("Missing config file");
XmlDocument xmlConfig = new XmlDocument();
xmlConfig.Load(_fileInfo.FullName);
string keyValue = null;
foreach(XmlNode node in xmlConfig["configuration"]["appSettings"])
if(node.Name == "add")
if(node.Attributes.GetNamedItem("key").Value == keyName)
keyValue = node.Attributes.GetNamedItem("value").Value;
return keyValue;
}//end class
}//end namespace declaration
