using System;
using System.Configuration;
using System.Collections.Specialized;
using EXT.DOMAIN.vbecs.DAL.VistALink.OpenLibrary;
namespace EXT.DOMAIN.vbecs.DAL.VistALink.Client
/// <summary>
/// Summary description for ClientConfig.
/// </summary>
public class ClientConfig
// Consts used to read settings from config file
private const string XMLCONSTS_CONFIG_CLIENT_SECTION_NAME = "Client";
private const string CONFIG_VALUE_SEND_TIMEOUT = "SendTimeoutInSeconds";
private const string CONFIG_VALUE_RECEIVE_TIMEOUT = "ReceiveTimeoutInSeconds";
private const string CONFIG_VALUE_RECEIVE_BUFFER_SIZE = "ReceiveBufferSize";
// Variables containing configured values
private static Timeout _sendTimeout;
private static Timeout _receiveTimeout;
private static int _receiveBufferSize;
/// <summary>
/// Class should not be instantiated.
/// </summary>
private ClientConfig() {}
/// <summary>
/// Initializes <see cref="ClientConfig"/> on first request.
/// </summary>
static ClientConfig()
SetDefaultHardcodedValues();
GetSettingsFromConfigFile();
/// <summary>
/// Receive buffer size in bytes.
/// </summary>
public static int ReceiveBufferSize
get
return _receiveBufferSize;
/// <summary>
/// Receive timeout. 
/// </summary>
public static Timeout ReceiveTimeout
get
return _receiveTimeout;
/// <summary>
/// Send timeout. 
/// </summary>
public static Timeout SendTimeout
get
return _sendTimeout;
/// <summary>
/// Sets default hardcoded values. 
/// </summary>
private static void SetDefaultHardcodedValues()
_sendTimeout = new Timeout( 10000 );
_receiveTimeout = new Timeout( 10000 );
_receiveBufferSize = 32768;
/// <summary>
/// Retrieves settings from application configuration file if they are available.
/// Overrides defaults for defined values only.
/// </summary>
private static void GetSettingsFromConfigFile()
NameValueCollection _configFileSettings = (NameValueCollection)ConfigurationSettings.GetConfig( GlobalConfig.GetXPathToChildConfigSection( XMLCONSTS_CONFIG_CLIENT_SECTION_NAME ) );
// Check if config section exists
if( _configFileSettings == null ) 
return;
if( _configFileSettings[ CONFIG_VALUE_RECEIVE_BUFFER_SIZE ] != null )
_receiveBufferSize = Int32.Parse( (string)_configFileSettings[ CONFIG_VALUE_RECEIVE_BUFFER_SIZE ] );
if( _configFileSettings[ CONFIG_VALUE_SEND_TIMEOUT ] != null )
_sendTimeout = Timeout.ParseStringInSeconds( (string)_configFileSettings[ CONFIG_VALUE_SEND_TIMEOUT ] );
if( _configFileSettings[ CONFIG_VALUE_RECEIVE_TIMEOUT ] != null )
_receiveTimeout = Timeout.ParseStringInSeconds( (string)_configFileSettings[ CONFIG_VALUE_RECEIVE_TIMEOUT ] );
