using System;
using System.Xml;
using System.Threading;
using System.Reflection;
using System.Runtime.Serialization;
using System.Runtime.Remoting;
using EXT.DOMAIN.vbecs.DAL.VistALink.OpenLibrary;
namespace EXT.DOMAIN.vbecs.DAL.VistALink.Listener.Core
/// <summary>
/// This class represents RPC configured and published on server.
/// 
/// The class deserializes itself from host application's XML configuration file 
/// and provides all means to authorize caller and execute configured published code. 
/// </summary>
public class PublishedProcedure
private readonly string _name;
private readonly string _assemblyNameLocation;
private readonly string _fullTypeName;
private readonly string _methodName;
private readonly PublishedProcedureSecurityInfo _securityInfo;
private readonly RpcParameterCollection _methodParameters;
private MethodInfo _boundMethod;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>7/30/2010</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="9106"> 
///
<ExpectedInput>Valid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="9107"> 
///
<ExpectedInput>Invalid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Constructor
/// </summary>
/// <param name="sourceNode"></param>
public PublishedProcedure( XmlNode sourceNode )
if( sourceNode == null )
throw( new ArgumentNullException( "sourceNode" ) );
XmlElement _rootElement = XmlUtility.ParseValidateConvertNodeToElement( sourceNode, "Rpc" );
XmlNodeList _childElements = XmlUtility.ParseGetChildElements( sourceNode );
if( _childElements.Count != 2 )
throw( new XmlParseException( "{0} node must have exactly 2 child elements - one containing parameters and another - security info." ) );
_name = XmlUtility.ParseGetRequiredAttributeValue( _rootElement, "name" );
_assemblyNameLocation = XmlUtility.ParseGetRequiredAttributeValue( _rootElement, "assemblyNameLocation" );
_fullTypeName = XmlUtility.ParseGetRequiredAttributeValue( _rootElement, "fullTypeName" );
_methodName = XmlUtility.ParseGetRequiredAttributeValue( _rootElement, "methodName" );
 RpcParameterCollection _bufParameters = RpcParameterCollection.Parse( _rootElement, new RpcParameterXmlFactory() );
for( int _paramIndex = 0; _paramIndex < _bufParameters.Count; _paramIndex++ )
if( !_bufParameters[ _paramIndex ].BaseType.IsSerializable )
throw( new XmlParseException( "Parameter at position {0} for published procedure {1} is not serializable." ) );
_methodParameters = _bufParameters;
_securityInfo = ParseGetSecurityInfo( _childElements[1] );
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>7/30/2010</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="9104"> 
///
<ExpectedInput>Valid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="9105"> 
///
<ExpectedInput>Invalid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Execute
/// </summary>
/// <param name="runDomain"></param>
/// <param name="evidence"></param>
/// <param name="parameters"></param>
/// <returns></returns>
public object Execute( AppDomain runDomain, CallerSecurityEvidence evidence, object[] parameters )
if( runDomain == null )
throw( new ArgumentNullException( "runDomain" ) );
if( evidence == null )
throw( new ArgumentNullException( "evidence" ) );
_securityInfo.Verify( evidence );
object _rpcContainerHandle = GetValidatedRpcContainerRef( runDomain );
if( _boundMethod == null )
_boundMethod = GetBoundMethodInfo( _rpcContainerHandle.GetType() );
try
if( _rpcContainerHandle is IDisposable )
using( (IDisposable)_rpcContainerHandle )
return _boundMethod.Invoke( _rpcContainerHandle, parameters );
else
return _boundMethod.Invoke( _rpcContainerHandle, parameters );
catch( TargetInvocationException xcp )
// TODO: remove string.format
throw( new VistALinkException( String.Format( "Exception occured in published procedure {0}.", xcp.InnerException.Message ), xcp.InnerException ) );
private MethodInfo GetBoundMethodInfo( Type containerType )
if( containerType == null )
throw( new ArgumentNullException( "containerType" ) );
MethodInfo _resultInfo = 
containerType.GetMethod(
_methodName, 
BindingFlags.Instance | BindingFlags.InvokeMethod | BindingFlags.ExactBinding | BindingFlags.Public, 
null,
CallingConventions.ExplicitThis | CallingConventions.HasThis, 
_methodParameters.GetBoundMethodSignatureAsParametersTypesArray(), 
null );
if( _resultInfo == null )
throw( new VistALinkException( "Unable to bind to method {0} of type {1} in assembly {2} for published procedure {3}." ) );
if( _resultInfo.ReturnType != null && !_resultInfo.ReturnType.IsSerializable )
throw( new VistALinkException( "Published procedure's {0} bound method's return type is neither void or serializable." ) );
return _resultInfo;
private object GetValidatedRpcContainerRef( AppDomain runDomain )
if( runDomain == null )
throw( new ArgumentNullException( "runDomain" ) );
object _rpcContainerHandle = null;
try
_rpcContainerHandle = runDomain.CreateInstanceFromAndUnwrap( 
_assemblyNameLocation, _fullTypeName, false, BindingFlags.ExactBinding | BindingFlags.Instance | BindingFlags.Public, null, null, null, null, null );
catch( TargetInvocationException xcp )
throw( new VistALinkException( "Unable to create published procedure container object for {0}. An exception occured in object's constructor.", xcp ) );
if( _rpcContainerHandle == null )
throw( new VistALinkException( String.Format( "Unable to create published procedure container object for {0}. Type {1} was not found in the assembly {2}.", this.Name, _assemblyNameLocation, _fullTypeName ) ) );
if( !(_rpcContainerHandle is MarshalByRefObject ) )
throw( new VistALinkException( String.Format( "Published procedure container object for '{0}' is not derived from MarshalByRefObject.", this.Name ) ) );
return _rpcContainerHandle;
/// <summary>
/// Parses supplied XML node and returns security info token deserialized from it. 
/// Used to provide derived classes with a possibility of using extended version of security info token.
/// </summary>
/// <param name="sourceNode">Source XML node to deserialize security info from.</param>
/// <returns>New instance of appropriate security info token deserialized from a supplied XML node.</returns>
protected static PublishedProcedureSecurityInfo ParseGetSecurityInfo( XmlNode sourceNode )
if( sourceNode == null )
throw( new ArgumentNullException( "sourceNode" ) );
return PublishedProcedureSecurityInfo.Parse( sourceNode );
/// <summary>
/// Get ConfiguredParameters
/// </summary>
protected RpcParameterCollection ConfiguredParameters
get
return _methodParameters;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>7/30/2010</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="9102"> 
///
<ExpectedInput>Valid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="9103"> 
///
<ExpectedInput>Invalid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Name of the remote procedure. 
/// This name must be unique within a server list. 
/// </summary>
public string Name
get
return _name;
