using System;
using System.Collections;
using System.Net;
using System.Xml;
using EXT.DOMAIN.vbecs.DAL.VistALink.OpenLibrary;
namespace EXT.DOMAIN.vbecs.DAL.VistALink.Listener.Core
/// <summary>
/// This class represents list of IP addresses that are 
/// granted access for published procedure on server.
/// 
/// Encapsulates deserialization from XML config and 
/// verification of access for supplied IP address. 
/// </summary>
public class PublishedProcedureIpAccessList
// Constants used in XML message serialization/deserialization
private const string XMLCONSTS_IP_ACCESS_LIST_NODE_NAME = "IpAccessList";
private const string XMLCONSTS_ALLOW_NODE_NAME = "allow";
private const string XMLCONSTS_IP_ATTRIBUTE_NAME = "ip";
private ArrayList _ipAccessList;
/// <summary>
/// Constructor accepting list of allowed IP addresses as <see cref="ArrayList"/>.
/// May be used by derived classes for extendability purposes. 
/// </summary>
/// <param name="ipAccessList">
///
ArrayList containing list of allowed IP addresses 
///
represented with <see cref="IPAddress"/> objects.
///
</param>
protected PublishedProcedureIpAccessList( ArrayList ipAccessList )
if( ipAccessList == null )
throw( new ArgumentNullException( "ipAccessList" ) );
_ipAccessList = ipAccessList;
/// <summary>
/// XML deserialization factory method creating new instance 
/// of the class from supplied <see cref="XmlNode"/>.
/// </summary>
/// <param name="sourceNode">Source <see cref="XmlNode"/> to parse and deserialize object from.</param>
/// <returns>Instance of the class deserialized from given <see cref="XmlNode"/>.</returns>
public static PublishedProcedureIpAccessList Parse( XmlNode sourceNode )
if( sourceNode == null )
throw( new ArgumentNullException( "sourceNode" ) );
XmlElement _listRootElement = XmlUtility.ParseValidateConvertNodeToElement( sourceNode, XMLCONSTS_IP_ACCESS_LIST_NODE_NAME );
ArrayList _prepIpAccessList = new ArrayList();
try
foreach( XmlElement _ipElement in XmlUtility.ParseGetChildElements( _listRootElement ) )
XmlUtility.ParseValidateConvertNodeToElement( _ipElement, XMLCONSTS_ALLOW_NODE_NAME );
_prepIpAccessList.Add( IPAddress.Parse( XmlUtility.ParseGetRequiredAttributeValue( _ipElement, XMLCONSTS_IP_ATTRIBUTE_NAME ) ) );
catch( FormatException xcp )
throw( new XmlParseException( "Unable to parse IP address in IP access list.", xcp ) );
return new PublishedProcedureIpAccessList( _prepIpAccessList );
/// <summary>
/// Verifies access for supplied IP address.
/// </summary>
/// <param name="clientIpToCheck">IP address to verify.</param>
/// <returns>True if a given IP address is allowed. Otherwise - false.</returns>
public bool IsIpAllowedAccess( IPAddress clientIpToCheck )
if( clientIpToCheck == null )
throw( new ArgumentNullException( "clientIpToCheck" ) );
return _ipAccessList.Contains( clientIpToCheck );
