using System;
using System.Collections.Specialized;
using System.Xml;
using EXT.DOMAIN.vbecs.DAL.VistALink.OpenLibrary;
namespace EXT.DOMAIN.vbecs.DAL.VistALink.Listener.Core
/// <summary>
/// This class represents list of published procedures on RPC server. 
/// 
/// The class deserializes itself from host application's XML configuration file 
/// and provides necessary functionality to locate published procedure by its name.
/// </summary>
public class PublishedProceduresCollection : NameObjectCollectionBase
// Constants used in XML message serialization/deserialization
private const string XMLCONSTS_RPCLIST_NODE_NAME = "RpcList";
/// <summary>
/// XML deserialization constructor. Parses <see cref="XmlNode"/> and returns new collection of published procedures
/// deserialized from supplied <see cref="XmlNode"/>.
/// </summary>
/// <param name="sourceNode"><see cref="XmlNode"/> to deserialize from.</param>
public PublishedProceduresCollection( XmlNode sourceNode )
: base()
if( sourceNode == null )
throw( new ArgumentNullException( "sourceNode" ) );
XmlElement _rootElement = XmlUtility.ParseValidateConvertNodeToElement( sourceNode, XMLCONSTS_RPCLIST_NODE_NAME );
try
foreach( XmlNode _singleRpcNode in XmlUtility.ParseGetChildElements( _rootElement ) )
Add( ParseGetPublishedProcedure( _singleRpcNode ) );
catch( ArgumentException xcp ) // there may be number of reasons to fail
throw( new XmlParseException( "Unable to parse supplied XML", xcp ) );
/// <summary>
/// Parses supplied <see cref="XmlNode"/> and returns new <see cref="PublishedProcedure"/> deserialized from it. 
/// Derived classes may override this method to fit the collection to specific <see cref="PublishedProcedure"/>
/// children.
/// </summary>
/// <param name="publishedProcedureNode">XML element to parse <see cref="PublishedProcedure"/> from.</param>
/// <returns><see cref="PublishedProcedure"/> deserialized from supplied <see cref="XmlNode"/>.</returns>
protected virtual PublishedProcedure ParseGetPublishedProcedure( XmlNode publishedProcedureNode )
if( publishedProcedureNode == null )
throw( new ArgumentNullException( "publishedProcedureNode" ) );
return new PublishedProcedure( publishedProcedureNode );
/// <summary>
/// Adds published procedure to collection. 
/// </summary>
/// <param name="procedureToAdd"><see cref="PublishedProcedure"/> to add.</param>
/// <returns>Reference to added <see cref="PublishedProcedure"/>.</returns>
protected PublishedProcedure Add( PublishedProcedure procedureToAdd )
if( procedureToAdd == null )
throw( new ArgumentNullException( "procedureToAdd" ) );
if( BaseGet( procedureToAdd.Name ) != null )
throw( new ArgumentException( "Published procedure with name {0} already exists in collection." ) );
BaseAdd( procedureToAdd.Name, procedureToAdd );
return procedureToAdd;
/// <summary>
/// This indexer allows access to <see cref="PublishedProcedure"/> by its name.
/// </summary>
public PublishedProcedure this[string procedureName]
get
return (PublishedProcedure)BaseGet( procedureName );
