using System;
using System.IO;
using System.Net.Sockets;
using EXT.DOMAIN.vbecs.DAL.VistALink.OpenLibrary;
using EXT.DOMAIN.vbecs.DAL.VistALink.OpenLibrary.Messages;
namespace EXT.DOMAIN.vbecs.DAL.VistALink.Listener.Core
/// <summary>
/// This class is a simple wrapper around TcpClient that sends and receives 
/// VistALink messages. It terminates connection in case of errors and allows only 
/// one pair of "send-receive" or "receive-send" calls (RR stands for Request-Response).
/// </summary>
public class VistALinkTestRRConnection : IDisposable
private static readonly VistALinkMessageXmlFactory _messageFactory = new VistALinkMessageXmlFactory( new RpcParameterXmlFactory() );
NetworkStream _stream;
TcpClient _client;
private int _numberOfSendReceiveOperationsPerformed;
private bool _messageSentFlag;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>7/30/2010</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="9070"> 
///
<ExpectedInput>Valid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="9071"> 
///
<ExpectedInput>Invalid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Constructor
/// </summary>
public VistALinkTestRRConnection( )
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>7/30/2010</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="9068"> 
///
<ExpectedInput>Valid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="9069"> 
///
<ExpectedInput>Invalid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// RegisterConnection
/// </summary>
/// <param name="client"></param>
public void RegisterConnection( TcpClient client )
if( client == null )
throw( new ArgumentNullException( "client" ) );
try
_numberOfSendReceiveOperationsPerformed = 0;
_client = client;
_stream = client.GetStream();
catch
Disconnect();
throw;
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>7/30/2010</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="9066"> 
///
<ExpectedInput>Valid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="9067"> 
///
<ExpectedInput>Invalid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// SendMessage
/// </summary>
/// <param name="messageToSend"></param>
public void SendMessage( VistALinkMessage messageToSend )
if( messageToSend == null )
throw( new ArgumentNullException( "messageToSend" ) );
CheckRegisterNetworkOperationPrerequisites( true );
try
byte[] _dataChunk = messageToSend.ToXmlByteArray();
_stream.Write( _dataChunk, 0, _dataChunk.Length );
_stream.WriteByte( GlobalConfig.EOTByte );
catch
Disconnect();
throw;
finally
CheckAndDisconnectIfNeeded();
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>7/30/2010</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="9064"> 
///
<ExpectedInput>Valid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="9065"> 
///
<ExpectedInput>Invalid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// ReceiveMessage
/// </summary>
/// <returns></returns>
public VistALinkMessage ReceiveMessage()
CheckRegisterNetworkOperationPrerequisites( false );
MemoryStream _ms;
try
byte[] _receiveBuffer = new byte[8192];
_ms = new MemoryStream( _receiveBuffer.Length );
for(;;)
int _bytesRead = _stream.Read( _receiveBuffer, 0, _receiveBuffer.Length );
if( _bytesRead <= 0 ) 
throw( new VistALinkException( "Connection lost - either remote party dropped a connection or network problems prevent normal communication. Unexpected end of transmission was encountered while receiving VistALink message from network. VistALink message was not properly terminated with the end-of-transmission character (ASCII code 4)." ) );
if( _receiveBuffer[_bytesRead - 1] == GlobalConfig.EOTByte )
_ms.Write( _receiveBuffer, 0, _bytesRead - 1 );
break;
else
_ms.Write( _receiveBuffer, 0, _bytesRead );
catch
Disconnect();
throw;
try
VistALinkMessage _msg = _messageFactory.ParseXmlCreateVistALinkMessage( GlobalConfig.NetworkMessageEncoding.GetString( _ms.ToArray() ) );
if( _msg == null ) 
throw( new VistALinkException( "Unknown message was received from remote party. It cannot be identified as a VistALink message." ) );
return _msg;
finally
CheckAndDisconnectIfNeeded();
private void CheckRegisterNetworkOperationPrerequisites( bool IsSend )
if( !IsConnected ) 
throw( new InvalidOperationException( "Not connected" ) );
if( _numberOfSendReceiveOperationsPerformed == 1 )
if( _messageSentFlag && IsSend )
throw( new InvalidOperationException( "Message was already send, call to receive was expected instead of repetitive call to receive" ) );
if( !_messageSentFlag && !IsSend )
throw( new InvalidOperationException( "Message was already received, call to send was expected instead of repetitive call to send" ) );
if( IsSend )
_messageSentFlag = true;
_numberOfSendReceiveOperationsPerformed++;
private void CheckAndDisconnectIfNeeded()
if( _numberOfSendReceiveOperationsPerformed == 2 )
Disconnect();
private void Disconnect()
try
if( _client != null )
_client.Close();
if( _stream != null )
_stream.Close();
finally
KillConnectionVariables();
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>7/30/2010</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="9062"> 
///
<ExpectedInput>Valid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="9063"> 
///
<ExpectedInput>Invalid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Close
/// </summary>
public void Close()
Dispose();
///<Developers>
///
<Developer></Developer>
///</Developers>
///<SiteName>Hines OIFO</SiteName>
///<CreationDate>7/30/2010</CreationDate>
///<TestCases>
///
///<Case type="0" testid ="9060"> 
///
<ExpectedInput>Valid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///<Case type="1" testid ="9061"> 
///
<ExpectedInput>Invalid</ExpectedInput>
///
<ExpectedOutput></ExpectedOutput>
///
</Case>
///
///</TestCases>
///<Update></Update>
///<ArchivePlan></ArchivePlan>
///<Interfaces></Interfaces>
///
/// <summary>
/// Dispose
/// </summary>
public void Dispose()
GC.SuppressFinalize( this );
Dispose( true );
private void Dispose( bool disposing )
lock( this )
if( disposing )
Disconnect();
KillConnectionVariables();
private void KillConnectionVariables()
_client = null;
_stream = null;
/// <summary>
/// Destructor
/// </summary>
~VistALinkTestRRConnection()
Dispose( false );
private bool IsConnected
get
return _client != null && _stream != null;
